<?php
session_start();
require_once('../includes/db_connect.php');

// Überprüfen, ob der Benutzer angemeldet ist
if (!isset($_SESSION['admin_logged_in']) || $_SESSION['admin_logged_in'] !== true) {
    header('Location: index.php');
    exit;
}

// Massenaktualisierung der Lagerbestände
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['update_inventory'])) {
    $success = true;
    $errorMessage = '';
    
    try {
        // Beginne eine Transaktion für Massenaktualisierung
        $conn->beginTransaction();
        
        foreach ($_POST['stock'] as $productId => $stockLevel) {
            $productId = (int)$productId;
            $stockLevel = (int)$stockLevel;
            $showStockInfo = isset($_POST['show_stock'][$productId]) ? 1 : 0;
            
            $stmt = $conn->prepare("UPDATE products SET stock_level = ?, show_stock_info = ? WHERE id = ?");
            $stmt->execute([$stockLevel, $showStockInfo, $productId]);
        }
        
        // Commit der Transaktion
        $conn->commit();
        $_SESSION['success_message'] = "Lagerbestände wurden erfolgreich aktualisiert.";
    } catch (PDOException $e) {
        // Rollback bei Fehler
        $conn->rollBack();
        $success = false;
        $errorMessage = $e->getMessage();
        $_SESSION['error_message'] = "Fehler beim Aktualisieren der Lagerbestände: " . $errorMessage;
    }
    
    // Redirect zur selben Seite, um doppelte Formularübermittlung zu vermeiden
    header('Location: inventory.php');
    exit;
}

// Alle Produkte abrufen
$stmt = $conn->prepare("SELECT * FROM products WHERE active = 1 ORDER BY sort_order, name");
$stmt->execute();
$products = $stmt->fetchAll();

// Seitentitel setzen und Header einfügen
$pageTitle = "Lagerbestand verwalten";
include('includes/header.php');
?>

<div class="page-header">
    <h3>Lagerbestand verwalten</h3>
    <div>
        <a href="products.php" class="btn btn-secondary">
            <i class="fas fa-arrow-left"></i> Zurück zur Produktübersicht
        </a>
    </div>
</div>

<?php if (isset($_SESSION['success_message'])): ?>
    <div class="alert alert-success">
        <?php 
        echo $_SESSION['success_message']; 
        unset($_SESSION['success_message']); 
        ?>
    </div>
<?php endif; ?>

<?php if (isset($_SESSION['error_message'])): ?>
    <div class="alert alert-danger">
        <?php 
        echo $_SESSION['error_message']; 
        unset($_SESSION['error_message']); 
        ?>
    </div>
<?php endif; ?>

<div class="card">
    <div class="card-body">
        <p>Hier können Sie den Lagerbestand aller Produkte gleichzeitig verwalten.</p>
        
        <form action="inventory.php" method="post">
            <div class="table-responsive">
                <table class="table">
                    <thead>
                        <tr>
                            <th style="width: 60px;">Bild</th>
                            <th>Produkt</th>
                            <th style="width: 150px;">Lagerbestand</th>
                            <th style="width: 150px;">Anzeigen?</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (count($products) > 0): ?>
                            <?php foreach ($products as $product): ?>
                                <tr>
                                    <td>
                                        <?php if (!empty($product['image_path']) && file_exists($product['image_path'])): ?>
                                            <img src="<?php echo htmlspecialchars($product['image_path']); ?>" alt="<?php echo htmlspecialchars($product['name']); ?>" style="max-width: 50px; max-height: 50px;">
                                        <?php else: ?>
                                            <i class="fas fa-box" style="font-size: 1.5rem; color: #ccc;"></i>
                                        <?php endif; ?>
                                    </td>
                                    <td>
                                        <strong><?php echo htmlspecialchars($product['name']); ?></strong>
                                    </td>
                                    <td>
                                        <input type="number" name="stock[<?php echo $product['id']; ?>]" class="form-control" value="<?php echo $product['stock_level']; ?>" min="0">
                                    </td>
                                    <td>
                                        <div class="custom-control custom-switch">
                                            <input type="checkbox" class="custom-control-input" id="show_stock_<?php echo $product['id']; ?>" name="show_stock[<?php echo $product['id']; ?>]" <?php echo $product['show_stock_info'] ? 'checked' : ''; ?>>
                                            <label class="custom-control-label" for="show_stock_<?php echo $product['id']; ?>">Lagerbestand anzeigen</label>
                                        </div>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php else: ?>
                            <tr>
                                <td colspan="4" class="text-center">Keine aktiven Produkte gefunden.</td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
            
            <?php if (count($products) > 0): ?>
                <div class="form-group text-center mt-4">
                    <button type="submit" name="update_inventory" class="btn btn-primary">
                        <i class="fas fa-save"></i> Alle Lagerbestände speichern
                    </button>
                </div>
            <?php endif; ?>
        </form>
    </div>
</div>

<script>
    // Optional: Funktion zum Hervorheben geänderter Felder
    document.addEventListener('DOMContentLoaded', function() {
        const inputs = document.querySelectorAll('input[type="number"], input[type="checkbox"]');
        inputs.forEach(input => {
            const originalValue = input.type === 'checkbox' ? input.checked : input.value;
            
            input.addEventListener('change', function() {
                const newValue = input.type === 'checkbox' ? input.checked : input.value;
                
                if (newValue !== originalValue) {
                    input.classList.add('border-warning');
                    
                    if (input.type === 'number') {
                        // Finde die Tabellenzeile und markiere sie
                        const row = input.closest('tr');
                        if (row) {
                            row.style.backgroundColor = 'rgba(255, 243, 205, 0.3)';
                        }
                    }
                }
            });
        });
    });
</script>

<?php include('includes/footer.php'); ?> 