<?php
// Gutschein-Funktionen

/**
 * Validiert einen Gutscheincode
 * @param PDO $conn Datenbankverbindung
 * @param string $code Gutscheincode
 * @param float $orderTotal Bestellsumme
 * @return array Ergebnis mit success, message, voucher_data
 */
function validateVoucher($conn, $code, $orderTotal) {
    try {
        // Gutschein aus Datenbank laden
        $stmt = $conn->prepare("SELECT * FROM vouchers WHERE code = ? AND active = 1");
        $stmt->execute([strtoupper(trim($code))]);
        $voucher = $stmt->fetch();
        
        if (!$voucher) {
            return [
                'success' => false,
                'message' => 'Gutscheincode ist ungültig.',
                'voucher_data' => null
            ];
        }
        
        // Gültigkeitszeitraum prüfen
        $today = date('Y-m-d');
        if ($voucher['valid_from'] > $today) {
            return [
                'success' => false,
                'message' => 'Dieser Gutschein ist noch nicht gültig. Gültig ab: ' . date('d.m.Y', strtotime($voucher['valid_from'])),
                'voucher_data' => null
            ];
        }
        
        if ($voucher['valid_until'] < $today) {
            return [
                'success' => false,
                'message' => 'Dieser Gutschein ist abgelaufen. Gültig bis: ' . date('d.m.Y', strtotime($voucher['valid_until'])),
                'voucher_data' => null
            ];
        }
        
        // Maximale Verwendungen prüfen
        if ($voucher['max_uses'] && $voucher['current_uses'] >= $voucher['max_uses']) {
            return [
                'success' => false,
                'message' => 'Dieser Gutschein wurde bereits zu oft verwendet.',
                'voucher_data' => null
            ];
        }
        
        // Mindestbestellwert prüfen
        if ($voucher['min_order_value'] > $orderTotal) {
            return [
                'success' => false,
                'message' => 'Mindestbestellwert von ' . number_format($voucher['min_order_value'], 2, ',', '.') . ' € nicht erreicht.',
                'voucher_data' => null
            ];
        }
        
        // Rabatt berechnen
        $discountAmount = calculateDiscount($voucher, $orderTotal);
        
        return [
            'success' => true,
            'message' => 'Gutschein erfolgreich angewendet!',
            'voucher_data' => $voucher,
            'discount_amount' => $discountAmount
        ];
        
    } catch (PDOException $e) {
        return [
            'success' => false,
            'message' => 'Fehler bei der Gutschein-Validierung.',
            'voucher_data' => null
        ];
    }
}

/**
 * Berechnet den Rabattbetrag
 * @param array $voucher Gutschein-Daten
 * @param float $orderTotal Bestellsumme
 * @return float Rabattbetrag
 */
function calculateDiscount($voucher, $orderTotal) {
    if ($voucher['discount_type'] === 'percentage') {
        return ($orderTotal * $voucher['discount_value']) / 100;
    } else {
        // Fester Betrag, aber nicht mehr als die Bestellsumme
        return min($voucher['discount_value'], $orderTotal);
    }
}

/**
 * Wendet einen Gutschein an und markiert ihn als verwendet
 * @param PDO $conn Datenbankverbindung
 * @param int $voucherId Gutschein-ID
 * @param float $discountAmount Rabattbetrag
 * @param float $orderTotal Bestellsumme
 * @param string $customerEmail Kunden-E-Mail
 * @param string $customerName Kundenname
 * @param int $orderId Bestell-ID (optional)
 * @return bool Erfolg
 */
function applyVoucher($conn, $voucherId, $discountAmount, $orderTotal, $customerEmail, $customerName, $orderId = null) {
    try {
        $conn->beginTransaction();
        
        // Verwendung in voucher_uses eintragen
        $stmt = $conn->prepare("INSERT INTO voucher_uses (voucher_id, order_id, customer_email, customer_name, discount_amount, order_total) VALUES (?, ?, ?, ?, ?, ?)");
        $stmt->execute([$voucherId, $orderId, $customerEmail, $customerName, $discountAmount, $orderTotal]);
        
        // Verwendungszähler in vouchers erhöhen
        $stmt = $conn->prepare("UPDATE vouchers SET current_uses = current_uses + 1 WHERE id = ?");
        $stmt->execute([$voucherId]);
        
        $conn->commit();
        return true;
        
    } catch (PDOException $e) {
        $conn->rollBack();
        return false;
    }
}

/**
 * Formatiert einen Preis für die Anzeige
 * @param float $price Preis
 * @return string Formatierter Preis
 */
function formatPrice($price) {
    return number_format($price, 2, ',', '.') . ' €';
}

/**
 * AJAX-Handler für Gutschein-Validierung
 */
if (isset($_POST['action']) && $_POST['action'] === 'validate_voucher') {
    require_once('db_connect.php');
    
    $code = $_POST['voucher_code'] ?? '';
    $orderTotal = floatval($_POST['order_total'] ?? 0);
    
    $result = validateVoucher($conn, $code, $orderTotal);
    
    header('Content-Type: application/json');
    echo json_encode($result);
    exit;
}
?> 