<?php
session_start();
require_once('../includes/db_connect.php');

// Check if user is logged in
if (!isset($_SESSION['admin_logged_in']) || $_SESSION['admin_logged_in'] !== true) {
    header('Location: index.php');
    exit;
}

$form_id = isset($_GET['id']) ? intval($_GET['id']) : 0;
$editing = $form_id > 0;

// Initialize variables
$form = [
    'id' => 0,
    'title' => '',
    'description' => '',
    'product_id' => null,
    'active' => 1
];

$fields = [];

// Load form data if editing
if ($editing) {
    try {
        $stmt = $conn->prepare("SELECT * FROM order_forms WHERE id = :id");
        $stmt->bindParam(':id', $form_id);
        $stmt->execute();
        
        $form_data = $stmt->fetch();
        
        if (!$form_data) {
            $_SESSION['error_message'] = 'Bestellformular nicht gefunden.';
            header('Location: order_forms.php');
            exit;
        }
        
        $form = $form_data;
        
        // Load form fields
        $stmt = $conn->prepare("SELECT * FROM form_fields WHERE form_id = :form_id ORDER BY sort_order");
        $stmt->bindParam(':form_id', $form_id);
        $stmt->execute();
        
        $fields = $stmt->fetchAll();
        
    } catch (PDOException $e) {
        $_SESSION['error_message'] = 'Fehler beim Laden des Formulars: ' . $e->getMessage();
        header('Location: order_forms.php');
        exit;
    }
}

// Save form
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['save_form'])) {
    $title = trim($_POST['title']);
    $description = trim($_POST['description']);
    $product_id = !empty($_POST['product_id']) ? intval($_POST['product_id']) : null;
    $active = isset($_POST['active']) ? 1 : 0;
    
    // Basic validation
    if (empty($title)) {
        $_SESSION['error_message'] = 'Bitte geben Sie einen Titel für das Formular ein.';
    } else {
        try {
            $conn->beginTransaction();
            
            if ($editing) {
                // Update existing form
                $stmt = $conn->prepare("
                    UPDATE order_forms 
                    SET title = :title, description = :description, product_id = :product_id, 
                        active = :active, updated_at = CURRENT_TIMESTAMP
                    WHERE id = :id
                ");
                $stmt->bindParam(':id', $form_id);
            } else {
                // Create new form
                $stmt = $conn->prepare("
                    INSERT INTO order_forms (title, description, product_id, active)
                    VALUES (:title, :description, :product_id, :active)
                ");
            }
            
            $stmt->bindParam(':title', $title);
            $stmt->bindParam(':description', $description);
            $stmt->bindParam(':product_id', $product_id, PDO::PARAM_INT);
            $stmt->bindParam(':active', $active);
            
            $stmt->execute();
            
            if (!$editing) {
                $form_id = $conn->lastInsertId();
            }
            
            // Process the fields if any were submitted
            if (isset($_POST['fields']) && is_array($_POST['fields'])) {
                
                // Delete existing fields if editing
                if ($editing) {
                    $stmt = $conn->prepare("DELETE FROM form_fields WHERE form_id = :form_id");
                    $stmt->bindParam(':form_id', $form_id);
                    $stmt->execute();
                }
                
                // Add new fields
                $stmt = $conn->prepare("
                    INSERT INTO form_fields (form_id, field_label, field_type, field_options, required, sort_order)
                    VALUES (:form_id, :field_label, :field_type, :field_options, :required, :sort_order)
                ");
                
                foreach ($_POST['fields'] as $index => $field) {
                    $field_label = trim($field['label']);
                    $field_type = $field['type'];
                    $field_options = isset($field['options']) ? trim($field['options']) : '';
                    $required = isset($field['required']) ? 1 : 0;
                    
                    // Skip empty fields
                    if (empty($field_label)) continue;
                    
                    $stmt->bindParam(':form_id', $form_id);
                    $stmt->bindParam(':field_label', $field_label);
                    $stmt->bindParam(':field_type', $field_type);
                    $stmt->bindParam(':field_options', $field_options);
                    $stmt->bindParam(':required', $required);
                    $stmt->bindParam(':sort_order', $index, PDO::PARAM_INT);
                    
                    $stmt->execute();
                }
            }
            
            $conn->commit();
            
            $_SESSION['success_message'] = $editing ? 
                'Bestellformular wurde erfolgreich aktualisiert.' : 
                'Bestellformular wurde erfolgreich erstellt.';
                
            header('Location: order_forms.php');
            exit;
            
        } catch (PDOException $e) {
            $conn->rollBack();
            $_SESSION['error_message'] = 'Fehler beim Speichern des Formulars: ' . $e->getMessage();
        }
    }
}

// Get products for dropdown
try {
    $stmt = $conn->prepare("SELECT id, name FROM products WHERE active = 1 ORDER BY name");
    $stmt->execute();
    $products = $stmt->fetchAll();
} catch (PDOException $e) {
    $_SESSION['error_message'] = 'Fehler beim Laden der Produkte: ' . $e->getMessage();
    $products = [];
}

// Include header
$pageTitle = $editing ? "Bestellformular bearbeiten" : "Neues Bestellformular";
include('includes/header.php');
?>

<div class="content-header">
    <h2><?php echo $pageTitle; ?></h2>
    <div class="content-header-actions">
        <a href="order_forms.php" class="btn btn-secondary">
            <i class="fas fa-arrow-left"></i> Zurück zur Übersicht
        </a>
    </div>
</div>

<form method="post" id="form-editor">
    <div class="row">
        <!-- Form Details -->
        <div class="col-md-4">
            <div class="card">
                <div class="card-header">
                    <h3>Formular-Details</h3>
                </div>
                <div class="card-body">
                    <div class="form-group">
                        <label for="title">Titel *</label>
                        <input type="text" id="title" name="title" class="form-control" 
                               value="<?php echo htmlspecialchars($form['title']); ?>" required>
                    </div>
                    
                    <div class="form-group">
                        <label for="description">Beschreibung</label>
                        <textarea id="description" name="description" class="form-control" rows="3"><?php echo htmlspecialchars($form['description']); ?></textarea>
                    </div>
                    
                    <div class="form-group">
                        <label for="product_id">Zugehöriges Produkt (optional)</label>
                        <select id="product_id" name="product_id" class="form-control">
                            <option value="">-- Kein Produkt --</option>
                            <?php foreach ($products as $product): ?>
                                <option value="<?php echo $product['id']; ?>" <?php echo ($form['product_id'] == $product['id']) ? 'selected' : ''; ?>>
                                    <?php echo htmlspecialchars($product['name']); ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                    
                    <div class="form-group">
                        <div class="custom-control custom-switch">
                            <input type="checkbox" class="custom-control-input" id="active" name="active" 
                                   value="1" <?php echo $form['active'] ? 'checked' : ''; ?>>
                            <label class="custom-control-label" for="active">Aktiv</label>
                        </div>
                    </div>
                </div>
            </div>
            
            <div class="card mt-4">
                <div class="card-header">
                    <h3>Feldtypen</h3>
                </div>
                <div class="card-body">
                    <p>Ziehen Sie die gewünschten Felder in den Formular-Builder.</p>
                    
                    <div class="field-types">
                        <div class="field-type" data-type="text" draggable="true">
                            <i class="fas fa-font"></i> Textfeld
                        </div>
                        <div class="field-type" data-type="email" draggable="true">
                            <i class="fas fa-envelope"></i> E-Mail
                        </div>
                        <div class="field-type" data-type="textarea" draggable="true">
                            <i class="fas fa-align-left"></i> Mehrzeiliger Text
                        </div>
                        <div class="field-type" data-type="address" draggable="true">
                            <i class="fas fa-map-marker-alt"></i> Adresse
                        </div>
                        <div class="field-type" data-type="select" draggable="true">
                            <i class="fas fa-caret-down"></i> Dropdown
                        </div>
                        <div class="field-type" data-type="checkbox" draggable="true">
                            <i class="fas fa-check-square"></i> Checkbox
                        </div>
                        <div class="field-type" data-type="radio" draggable="true">
                            <i class="fas fa-dot-circle"></i> Radio-Buttons
                        </div>
                    </div>
                </div>
            </div>
        </div>
        
        <!-- Form Builder -->
        <div class="col-md-8">
            <div class="card">
                <div class="card-header">
                    <h3>Formular-Builder</h3>
                </div>
                <div class="card-body">
                    <div id="form-fields" class="form-builder-area">
                        <?php if (empty($fields)): ?>
                            <div class="empty-form-message">
                                <i class="fas fa-info-circle"></i>
                                <p>Ziehen Sie Felder aus der linken Spalte hierher, um Ihr Formular zu erstellen.</p>
                            </div>
                        <?php else: ?>
                            <?php foreach ($fields as $index => $field): ?>
                                <div class="form-field" data-type="<?php echo htmlspecialchars($field['field_type']); ?>">
                                    <div class="field-header">
                                        <span class="field-drag-handle"><i class="fas fa-grip-lines"></i></span>
                                        <span class="field-type-icon">
                                            <?php
                                            $icon = '';
                                            switch ($field['field_type']) {
                                                case 'text': $icon = 'font'; break;
                                                case 'email': $icon = 'envelope'; break;
                                                case 'textarea': $icon = 'align-left'; break;
                                                case 'address': $icon = 'map-marker-alt'; break;
                                                case 'select': $icon = 'caret-down'; break;
                                                case 'checkbox': $icon = 'check-square'; break;
                                                case 'radio': $icon = 'dot-circle'; break;
                                                default: $icon = 'question-circle';
                                            }
                                            ?>
                                            <i class="fas fa-<?php echo $icon; ?>"></i>
                                        </span>
                                        <span class="field-title"><?php echo htmlspecialchars($field['field_label']); ?></span>
                                        <div class="field-actions">
                                            <button type="button" class="btn btn-sm btn-info edit-field"><i class="fas fa-edit"></i></button>
                                            <button type="button" class="btn btn-sm btn-danger delete-field"><i class="fas fa-trash-alt"></i></button>
                                        </div>
                                    </div>
                                    <div class="field-settings" style="display: none;">
                                        <div class="form-group">
                                            <label>Beschriftung</label>
                                            <input type="text" name="fields[<?php echo $index; ?>][label]" class="form-control field-label-input" value="<?php echo htmlspecialchars($field['field_label']); ?>">
                                        </div>
                                        
                                        <?php if (in_array($field['field_type'], ['select', 'checkbox', 'radio'])): ?>
                                            <div class="form-group">
                                                <label>Optionen (eine Option pro Zeile)</label>
                                                <textarea name="fields[<?php echo $index; ?>][options]" class="form-control field-options" rows="3"><?php echo htmlspecialchars($field['field_options']); ?></textarea>
                                            </div>
                                        <?php else: ?>
                                            <input type="hidden" name="fields[<?php echo $index; ?>][options]" value="">
                                        <?php endif; ?>
                                        
                                        <div class="form-group">
                                            <div class="custom-control custom-switch">
                                                <input type="checkbox" class="custom-control-input" id="field_required_<?php echo $index; ?>" 
                                                       name="fields[<?php echo $index; ?>][required]" value="1" <?php echo $field['required'] ? 'checked' : ''; ?>>
                                                <label class="custom-control-label" for="field_required_<?php echo $index; ?>">Pflichtfeld</label>
                                            </div>
                                        </div>
                                        
                                        <select name="fields[<?php echo $index; ?>][type]" class="form-control field-type" <?php echo $field['field_type'] === 'address' ? 'disabled' : ''; ?>>
                                            <option value="text" <?php echo $field['field_type'] === 'text' ? 'selected' : ''; ?>>Text (Einzeilig)</option>
                                            <option value="textarea" <?php echo $field['field_type'] === 'textarea' ? 'selected' : ''; ?>>Text (Mehrzeilig)</option>
                                            <option value="email" <?php echo $field['field_type'] === 'email' ? 'selected' : ''; ?>>E-Mail</option>
                                            <option value="tel" <?php echo $field['field_type'] === 'tel' ? 'selected' : ''; ?>>Telefon</option>
                                            <option value="number" <?php echo $field['field_type'] === 'number' ? 'selected' : ''; ?>>Nummer</option>
                                            <option value="address" <?php echo $field['field_type'] === 'address' ? 'selected' : ''; ?>>Adresse</option>
                                            <option value="select" <?php echo $field['field_type'] === 'select' ? 'selected' : ''; ?>>Dropdown</option>
                                            <option value="radio" <?php echo $field['field_type'] === 'radio' ? 'selected' : ''; ?>>Radio Buttons</option>
                                            <option value="checkbox" <?php echo $field['field_type'] === 'checkbox' ? 'selected' : ''; ?>>Checkboxen</option>
                                        </select>
                                        <?php if ($field['field_type'] === 'address'): ?>
                                            <div class="alert alert-info mt-2">
                                                <small>Das Adressfeld enthält automatisch Eingabefelder für Straße, Hausnummer, PLZ und Stadt.</small>
                                            </div>
                                            <input type="hidden" name="fields[<?php echo $index; ?>][type]" value="address">
                                        <?php endif; ?>
                                    </div>
                                </div>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </div>
                </div>
            </div>
            
            <div class="form-actions mt-4">
                <button type="submit" name="save_form" class="btn btn-primary">
                    <i class="fas fa-save"></i> Formular speichern
                </button>
            </div>
        </div>
    </div>
</form>

<script>
document.addEventListener('DOMContentLoaded', function() {
    const formFields = document.getElementById('form-fields');
    const fieldTypes = document.querySelectorAll('.field-type');
    let draggedItem = null;
    let fieldCounter = <?php echo count($fields); ?>;
    
    // Make field types draggable
    fieldTypes.forEach(type => {
        type.addEventListener('dragstart', function(e) {
            draggedItem = this;
            e.dataTransfer.setData('text/plain', this.dataset.type);
            setTimeout(() => this.classList.add('dragging'), 0);
        });
        
        type.addEventListener('dragend', function() {
            this.classList.remove('dragging');
            draggedItem = null;
        });
    });
    
    // Make form fields area a drop target
    formFields.addEventListener('dragover', function(e) {
        e.preventDefault();
        this.classList.add('drag-over');
    });
    
    formFields.addEventListener('dragleave', function() {
        this.classList.remove('drag-over');
    });
    
    formFields.addEventListener('drop', function(e) {
        e.preventDefault();
        this.classList.remove('drag-over');
        
        // Check if dropping a new field type or reordering
        if (draggedItem && draggedItem.classList.contains('field-type')) {
            // New field from the sidebar
            const fieldType = e.dataTransfer.getData('text/plain');
            addNewField(fieldType, fieldCounter++);
            
            // Remove empty message if it exists
            const emptyMessage = document.querySelector('.empty-form-message');
            if (emptyMessage) {
                emptyMessage.remove();
            }
        }
    });
    
    // Setup existing fields or create new ones
    const setupFieldLabel = (field) => {
        // Wenn es ein Adressfeld ist, verhindere die Änderung von Label und Typ
        if (field.dataset.type === 'address' || field.querySelector('.field-title').textContent.toLowerCase() === 'adresse') {
            // Setze das Feld-Label auf 'Adresse'
            const labelInput = field.querySelector('.field-label-input');
            if (labelInput) {
                labelInput.value = 'Adresse';
                labelInput.setAttribute('readonly', 'readonly');
            }
            
            // Aktualisiere den Typ auf 'address'
            const typeSelect = field.querySelector('.field-type');
            if (typeSelect) {
                typeSelect.value = 'address';
                typeSelect.setAttribute('disabled', 'disabled');
            }
            
            // Füge eine Hilfe-Info hinzu
            const infoExists = field.querySelector('.address-info');
            if (!infoExists) {
                const settings = field.querySelector('.field-settings');
                if (settings) {
                    const infoBox = document.createElement('div');
                    infoBox.className = 'alert alert-info mt-2 address-info';
                    infoBox.innerHTML = '<small>Das Adressfeld enthält automatisch Eingabefelder für Straße, Hausnummer, PLZ und Stadt.</small>';
                    
                    // Füge ein verstecktes Feld hinzu, um sicherzustellen, dass der Typ korrekt übermittelt wird
                    const hiddenType = document.createElement('input');
                    hiddenType.type = 'hidden';
                    hiddenType.name = typeSelect.name;
                    hiddenType.value = 'address';
                    
                    settings.appendChild(infoBox);
                    settings.appendChild(hiddenType);
                }
            }
            
            // Setze das required-Attribut auf true
            const requiredCheckbox = field.querySelector('input[type="checkbox"][name*="[required]"]');
            if (requiredCheckbox) {
                requiredCheckbox.checked = true;
            }
        }
    };
    
    // Add click handlers for existing fields
    setupExistingFields();
    
    function setupExistingFields() {
        // Edit button
        document.querySelectorAll('.form-field').forEach(field => {
            setupFieldLabel(field);
        });
        
        document.querySelectorAll('.edit-field').forEach(button => {
            button.addEventListener('click', function() {
                const field = this.closest('.form-field');
                const settings = field.querySelector('.field-settings');
                
                if (settings.style.display === 'none' || !settings.style.display) {
                    settings.style.display = 'block';
                    this.innerHTML = '<i class="fas fa-chevron-up"></i>';
                } else {
                    settings.style.display = 'none';
                    this.innerHTML = '<i class="fas fa-edit"></i>';
                }
            });
        });
        
        // Delete button
        document.querySelectorAll('.delete-field').forEach(button => {
            button.addEventListener('click', function() {
                if (confirm('Möchten Sie dieses Feld wirklich löschen?')) {
                    const field = this.closest('.form-field');
                    field.remove();
                    
                    // Update field indices
                    updateFieldIndices();
                    
                    // Show empty message if no fields left
                    if (formFields.children.length === 0) {
                        const emptyMessage = document.createElement('div');
                        emptyMessage.className = 'empty-form-message';
                        emptyMessage.innerHTML = `
                            <i class="fas fa-info-circle"></i>
                            <p>Ziehen Sie Felder aus der linken Spalte hierher, um Ihr Formular zu erstellen.</p>
                        `;
                        formFields.appendChild(emptyMessage);
                    }
                }
            });
        });
        
        // Update label when typing
        document.querySelectorAll('.field-label-input').forEach(input => {
            input.addEventListener('input', function() {
                const field = this.closest('.form-field');
                field.querySelector('.field-title').textContent = this.value;
            });
        });
    }
    
    function addNewField(type, index) {
        let iconClass = '';
        switch (type) {
            case 'text': iconClass = 'font'; break;
            case 'email': iconClass = 'envelope'; break;
            case 'textarea': iconClass = 'align-left'; break;
            case 'address': iconClass = 'map-marker-alt'; break;
            case 'select': iconClass = 'caret-down'; break;
            case 'checkbox': iconClass = 'check-square'; break;
            case 'radio': iconClass = 'dot-circle'; break;
            case 'tel': iconClass = 'phone'; break;
            default: iconClass = 'question-circle';
        }
        
        // Für Adressfelder automatisch die Beschriftung setzen
        const defaultLabel = type === 'address' ? 'Adresse' : 'Neues Feld';
        
        const fieldHTML = `
            <div class="form-field" data-type="${type}">
                <div class="field-header">
                    <span class="field-drag-handle"><i class="fas fa-grip-lines"></i></span>
                    <span class="field-type-icon"><i class="fas fa-${iconClass}"></i></span>
                    <span class="field-title">${defaultLabel}</span>
                    <div class="field-actions">
                        <button type="button" class="btn btn-sm btn-info edit-field"><i class="fas fa-edit"></i></button>
                        <button type="button" class="btn btn-sm btn-danger delete-field"><i class="fas fa-trash-alt"></i></button>
                    </div>
                </div>
                <div class="field-settings">
                    <div class="form-group">
                        <label>Beschriftung</label>
                        <input type="text" name="fields[${index}][label]" class="form-control field-label-input" 
                               value="${defaultLabel}" ${type === 'address' ? 'readonly' : ''}>
                    </div>
                    
                    ${(type === 'select' || type === 'checkbox' || type === 'radio') ? `
                        <div class="form-group">
                            <label>Optionen (eine Option pro Zeile)</label>
                            <textarea name="fields[${index}][options]" class="form-control field-options" rows="3">Option 1\nOption 2\nOption 3</textarea>
                        </div>
                    ` : `
                        <input type="hidden" name="fields[${index}][options]" value="">
                    `}
                    
                    <div class="form-group">
                        <div class="custom-control custom-switch">
                            <input type="checkbox" class="custom-control-input" id="field_required_${index}" 
                                   name="fields[${index}][required]" value="1" ${type === 'address' ? 'checked' : ''}>
                            <label class="custom-control-label" for="field_required_${index}">Pflichtfeld</label>
                        </div>
                    </div>
                    
                    <select name="fields[${index}][type]" class="form-control field-type" ${type === 'address' ? 'disabled' : ''}>
                        <option value="text" ${type === 'text' ? 'selected' : ''}>Text (Einzeilig)</option>
                        <option value="textarea" ${type === 'textarea' ? 'selected' : ''}>Text (Mehrzeilig)</option>
                        <option value="email" ${type === 'email' ? 'selected' : ''}>E-Mail</option>
                        <option value="tel" ${type === 'tel' ? 'selected' : ''}>Telefon</option>
                        <option value="number" ${type === 'number' ? 'selected' : ''}>Nummer</option>
                        <option value="address" ${type === 'address' ? 'selected' : ''}>Adresse</option>
                        <option value="select" ${type === 'select' ? 'selected' : ''}>Dropdown</option>
                        <option value="radio" ${type === 'radio' ? 'selected' : ''}>Radio Buttons</option>
                        <option value="checkbox" ${type === 'checkbox' ? 'selected' : ''}>Checkboxen</option>
                    </select>
                    ${type === 'address' ? `
                        <div class="alert alert-info mt-2">
                            <small>Das Adressfeld enthält automatisch Eingabefelder für Straße, Hausnummer, PLZ und Stadt.</small>
                        </div>
                        <input type="hidden" name="fields[${index}][type]" value="address">
                    ` : ''}
                </div>
            </div>
        `;
        
        const tempContainer = document.createElement('div');
        tempContainer.innerHTML = fieldHTML;
        const newField = tempContainer.firstElementChild;
        
        formFields.appendChild(newField);
        
        // Add event listeners to the new field
        const editButton = newField.querySelector('.edit-field');
        editButton.addEventListener('click', function() {
            const settings = newField.querySelector('.field-settings');
            
            if (settings.style.display === 'none' || !settings.style.display) {
                settings.style.display = 'block';
                this.innerHTML = '<i class="fas fa-chevron-up"></i>';
            } else {
                settings.style.display = 'none';
                this.innerHTML = '<i class="fas fa-edit"></i>';
            }
        });
        
        const deleteButton = newField.querySelector('.delete-field');
        deleteButton.addEventListener('click', function() {
            if (confirm('Möchten Sie dieses Feld wirklich löschen?')) {
                newField.remove();
                
                // Update field indices
                updateFieldIndices();
                
                // Show empty message if no fields left
                if (formFields.children.length === 0) {
                    const emptyMessage = document.createElement('div');
                    emptyMessage.className = 'empty-form-message';
                    emptyMessage.innerHTML = `
                        <i class="fas fa-info-circle"></i>
                        <p>Ziehen Sie Felder aus der linken Spalte hierher, um Ihr Formular zu erstellen.</p>
                    `;
                    formFields.appendChild(emptyMessage);
                }
            }
        });
        
        const labelInput = newField.querySelector('.field-label-input');
        labelInput.addEventListener('input', function() {
            newField.querySelector('.field-title').textContent = this.value;
        });
        
        // Automatically open the settings for the new field
        editButton.click();
    }
    
    function updateFieldIndices() {
        const fields = formFields.querySelectorAll('.form-field');
        fields.forEach((field, index) => {
            // Update input names
            field.querySelectorAll('[name^="fields["]').forEach(input => {
                const nameMatch = input.name.match(/fields\[\d+\]\[([^\]]+)\]/);
                if (nameMatch) {
                    const prop = nameMatch[1];
                    input.name = `fields[${index}][${prop}]`;
                }
            });
            
            // Update required checkbox ID
            const requiredCheck = field.querySelector('[id^="field_required_"]');
            if (requiredCheck) {
                const oldId = requiredCheck.id;
                const newId = `field_required_${index}`;
                requiredCheck.id = newId;
                
                // Update corresponding label
                const label = field.querySelector(`label[for="${oldId}"]`);
                if (label) {
                    label.setAttribute('for', newId);
                }
            }
        });
    }
    
    // Form submission validation
    document.getElementById('form-editor').addEventListener('submit', function(e) {
        const title = document.getElementById('title').value.trim();
        if (!title) {
            e.preventDefault();
            alert('Bitte geben Sie einen Titel für das Formular ein.');
            return;
        }
        
        const fields = formFields.querySelectorAll('.form-field');
        if (fields.length === 0 && !document.querySelector('.empty-form-message')) {
            e.preventDefault();
            alert('Bitte fügen Sie mindestens ein Feld zum Formular hinzu.');
            return;
        }
        
        // Make sure all visible fields have labels
        let valid = true;
        fields.forEach(field => {
            const labelInput = field.querySelector('.field-label-input');
            if (labelInput && !labelInput.value.trim()) {
                valid = false;
                labelInput.classList.add('is-invalid');
            } else if (labelInput) {
                labelInput.classList.remove('is-invalid');
            }
        });
        
        if (!valid) {
            e.preventDefault();
            alert('Bitte geben Sie für alle Felder eine Beschriftung ein.');
        }
    });
});
</script>

<style>
/* Form Builder Styles */
.field-types {
    display: flex;
    flex-wrap: wrap;
    gap: 10px;
    margin-bottom: 15px;
}

.field-type {
    background-color: #f8f9fa;
    border: 1px solid #ddd;
    border-radius: 4px;
    padding: 8px 12px;
    cursor: grab;
    transition: all 0.2s;
    user-select: none;
}

.field-type:hover {
    background-color: #e9ecef;
}

.field-type.dragging {
    opacity: 0.5;
}

.form-builder-area {
    min-height: 200px;
    border: 2px dashed #ddd;
    border-radius: 4px;
    padding: 15px;
    background-color: #f8f9fa;
}

.form-builder-area.drag-over {
    border-color: #007bff;
    background-color: rgba(0, 123, 255, 0.05);
}

.empty-form-message {
    display: flex;
    flex-direction: column;
    align-items: center;
    justify-content: center;
    color: #6c757d;
    height: 150px;
    text-align: center;
}

.empty-form-message i {
    font-size: 2rem;
    margin-bottom: 10px;
}

.form-field {
    background-color: white;
    border: 1px solid #ddd;
    border-radius: 4px;
    margin-bottom: 10px;
    box-shadow: 0 1px 3px rgba(0,0,0,0.1);
}

.field-header {
    display: flex;
    align-items: center;
    padding: 10px 15px;
    background-color: #f8f9fa;
    border-bottom: 1px solid #ddd;
}

.field-drag-handle {
    cursor: grab;
    margin-right: 10px;
    color: #6c757d;
}

.field-type-icon {
    margin-right: 10px;
    width: 20px;
    text-align: center;
}

.field-title {
    flex-grow: 1;
    font-weight: 500;
}

.field-actions {
    display: flex;
    gap: 5px;
}

.field-settings {
    padding: 15px;
    border-top: 1px solid #eee;
    background-color: #fff;
}
</style>

<?php include('includes/footer.php'); ?> 