<?php
session_start();
require_once('../includes/db_connect.php');

// Check if user is logged in
if (!isset($_SESSION['admin_logged_in']) || $_SESSION['admin_logged_in'] !== true) {
    header('Location: index.php');
    exit;
}

// Handle delete form
if (isset($_POST['delete_form'])) {
    $form_id = $_POST['form_id'];
    
    try {
        // Delete the form (cascades to fields due to foreign key constraints)
        $stmt = $conn->prepare("DELETE FROM order_forms WHERE id = :id");
        $stmt->bindParam(':id', $form_id);
        $stmt->execute();
        
        $_SESSION['success_message'] = 'Bestellformular erfolgreich gelöscht.';
    } catch (PDOException $e) {
        $_SESSION['error_message'] = 'Fehler beim Löschen des Bestellformulars: ' . $e->getMessage();
    }
    
    header('Location: order_forms.php');
    exit;
}

// Toggle form active status
if (isset($_POST['toggle_active'])) {
    $form_id = $_POST['form_id'];
    $new_status = $_POST['status'] == '1' ? 0 : 1;
    
    try {
        $stmt = $conn->prepare("UPDATE order_forms SET active = :status WHERE id = :id");
        $stmt->bindParam(':status', $new_status);
        $stmt->bindParam(':id', $form_id);
        $stmt->execute();
        
        $_SESSION['success_message'] = 'Status des Bestellformulars aktualisiert.';
    } catch (PDOException $e) {
        $_SESSION['error_message'] = 'Fehler beim Aktualisieren des Status: ' . $e->getMessage();
    }
    
    header('Location: order_forms.php');
    exit;
}

// Get all forms
try {
    $stmt = $conn->prepare("
        SELECT f.*, p.name as product_name,
        (SELECT COUNT(*) FROM form_fields WHERE form_id = f.id) as field_count,
        (SELECT COUNT(*) FROM order_submissions WHERE form_id = f.id) as submission_count
        FROM order_forms f
        LEFT JOIN products p ON f.product_id = p.id
        ORDER BY f.created_at DESC
    ");
    $stmt->execute();
    $forms = $stmt->fetchAll();
} catch (PDOException $e) {
    $_SESSION['error_message'] = 'Fehler beim Laden der Bestellformulare: ' . $e->getMessage();
    $forms = [];
}

// Get products for dropdown
try {
    $stmt = $conn->prepare("SELECT id, name FROM products WHERE active = 1 ORDER BY name");
    $stmt->execute();
    $products = $stmt->fetchAll();
} catch (PDOException $e) {
    $_SESSION['error_message'] = 'Fehler beim Laden der Produkte: ' . $e->getMessage();
    $products = [];
}

// Include header
$pageTitle = "Bestellformulare";
include('includes/header.php');
?>

<div class="content-header">
    <h2>Bestellformulare verwalten</h2>
    <div class="content-header-actions">
        <a href="order_form_edit.php" class="btn btn-primary">
            <i class="fas fa-plus"></i> Neues Formular erstellen
        </a>
    </div>
</div>

<div class="card">
    <div class="card-body">
        <?php if (count($forms) > 0): ?>
            <div class="table-responsive">
                <table class="admin-table">
                    <thead>
                        <tr>
                            <th>Titel</th>
                            <th>Beschreibung</th>
                            <th>Produkt</th>
                            <th>Felder</th>
                            <th>Einsendungen</th>
                            <th>Status</th>
                            <th>Aktionen</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($forms as $form): ?>
                            <tr>
                                <td><?php echo htmlspecialchars($form['title']); ?></td>
                                <td>
                                    <?php 
                                    $desc = $form['description'] ? htmlspecialchars($form['description']) : 'Keine Beschreibung';
                                    echo substr($desc, 0, 50) . (strlen($desc) > 50 ? '...' : '');
                                    ?>
                                </td>
                                <td><?php echo $form['product_name'] ? htmlspecialchars($form['product_name']) : 'Kein Produkt'; ?></td>
                                <td><?php echo $form['field_count']; ?></td>
                                <td>
                                    <?php if ($form['submission_count'] > 0): ?>
                                        <a href="order_submissions.php?form_id=<?php echo $form['id']; ?>" class="badge badge-info">
                                            <?php echo $form['submission_count']; ?> Einsendungen
                                        </a>
                                    <?php else: ?>
                                        <span class="badge badge-secondary">0 Einsendungen</span>
                                    <?php endif; ?>
                                </td>
                                <td>
                                    <form method="post" style="display: inline;">
                                        <input type="hidden" name="form_id" value="<?php echo $form['id']; ?>">
                                        <input type="hidden" name="status" value="<?php echo $form['active']; ?>">
                                        <button type="submit" name="toggle_active" class="btn btn-sm <?php echo $form['active'] ? 'btn-success' : 'btn-secondary'; ?>">
                                            <?php echo $form['active'] ? 'Aktiv' : 'Inaktiv'; ?>
                                        </button>
                                    </form>
                                </td>
                                <td class="actions">
                                    <a href="order_form_edit.php?id=<?php echo $form['id']; ?>" class="btn btn-sm btn-info" title="Bearbeiten">
                                        <i class="fas fa-edit"></i>
                                    </a>
                                    <form method="post" style="display: inline;" onsubmit="return confirm('Möchten Sie dieses Formular wirklich löschen? Dies kann nicht rückgängig gemacht werden.');">
                                        <input type="hidden" name="form_id" value="<?php echo $form['id']; ?>">
                                        <button type="submit" name="delete_form" class="btn btn-sm btn-danger" title="Löschen">
                                            <i class="fas fa-trash-alt"></i>
                                        </button>
                                    </form>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        <?php else: ?>
            <div class="alert alert-info">
                <i class="fas fa-info-circle"></i> Noch keine Bestellformulare erstellt. Klicken Sie auf "Neues Formular erstellen", um zu beginnen.
            </div>
        <?php endif; ?>
    </div>
</div>

<?php include('includes/footer.php'); ?> 