<?php
session_start();
require_once('../includes/db_connect.php');

// Check if user is logged in
if (!isset($_SESSION['admin_logged_in']) || $_SESSION['admin_logged_in'] !== true) {
    header('Location: index.php');
    exit;
}

// Get form ID if provided
$form_id = isset($_GET['form_id']) ? intval($_GET['form_id']) : 0;

// Handle marking submission as processed
if (isset($_POST['mark_processed'])) {
    $submission_id = intval($_POST['submission_id']);
    $processed = isset($_POST['processed']) ? intval($_POST['processed']) : 0;
    
    try {
        $stmt = $conn->prepare("
            UPDATE order_submissions 
            SET processed = :processed 
            WHERE id = :id
        ");
        $stmt->bindParam(':processed', $processed, PDO::PARAM_INT);
        $stmt->bindParam(':id', $submission_id, PDO::PARAM_INT);
        $stmt->execute();
        
        $_SESSION['success_message'] = 'Status der Bestellung aktualisiert.';
    } catch (PDOException $e) {
        $_SESSION['error_message'] = 'Fehler beim Aktualisieren des Status: ' . $e->getMessage();
    }
    
    // Redirect to maintain the same filters
    header('Location: ' . $_SERVER['HTTP_REFERER']);
    exit;
}

// Handle delete submission
if (isset($_POST['delete_submission'])) {
    $submission_id = intval($_POST['submission_id']);
    
    try {
        $stmt = $conn->prepare("DELETE FROM order_submissions WHERE id = :id");
        $stmt->bindParam(':id', $submission_id, PDO::PARAM_INT);
        $stmt->execute();
        
        $_SESSION['success_message'] = 'Bestellung erfolgreich gelöscht.';
    } catch (PDOException $e) {
        $_SESSION['error_message'] = 'Fehler beim Löschen der Bestellung: ' . $e->getMessage();
    }
    
    // Redirect to maintain the same filters
    header('Location: ' . $_SERVER['HTTP_REFERER']);
    exit;
}

// Build query for submissions
$params = [];
$where_clauses = [];

if ($form_id > 0) {
    $where_clauses[] = "s.form_id = :form_id";
    $params[':form_id'] = $form_id;
    
    // Get form info
    try {
        $stmt = $conn->prepare("SELECT title FROM order_forms WHERE id = :id");
        $stmt->bindParam(':id', $form_id);
        $stmt->execute();
        $form = $stmt->fetch();
    } catch (PDOException $e) {
        $_SESSION['error_message'] = 'Fehler beim Laden des Formulars: ' . $e->getMessage();
    }
}

// Processed filter
$processed_filter = isset($_GET['processed']) ? $_GET['processed'] : 'all';
if ($processed_filter !== 'all') {
    $processed_value = ($processed_filter === 'yes') ? 1 : 0;
    $where_clauses[] = "s.processed = :processed";
    $params[':processed'] = $processed_value;
}

// Search by customer name or email
$search = isset($_GET['search']) ? trim($_GET['search']) : '';
if (!empty($search)) {
    $where_clauses[] = "(s.customer_name LIKE :search OR s.customer_email LIKE :search)";
    $params[':search'] = "%$search%";
}

// Date range filter
$start_date = isset($_GET['start_date']) ? $_GET['start_date'] : '';
$end_date = isset($_GET['end_date']) ? $_GET['end_date'] : '';

if (!empty($start_date)) {
    $where_clauses[] = "s.created_at >= :start_date";
    $params[':start_date'] = $start_date . ' 00:00:00';
}

if (!empty($end_date)) {
    $where_clauses[] = "s.created_at <= :end_date";
    $params[':end_date'] = $end_date . ' 23:59:59';
}

// Build the where clause
$where_sql = '';
if (!empty($where_clauses)) {
    $where_sql = "WHERE " . implode(' AND ', $where_clauses);
}

// Get submissions with pagination
$current_page = isset($_GET['page']) ? max(1, intval($_GET['page'])) : 1;
$per_page = 20;
$offset = ($current_page - 1) * $per_page;

try {
    // Count total submissions for pagination
    $count_sql = "SELECT COUNT(*) FROM order_submissions s $where_sql";
    $stmt = $conn->prepare($count_sql);
    foreach ($params as $key => $value) {
        $stmt->bindValue($key, $value);
    }
    $stmt->execute();
    $total_submissions = $stmt->fetchColumn();
    
    // Get submissions with details
    $sql = "
        SELECT s.*, 
               f.title as form_title,
               p.name as product_name
        FROM order_submissions s
        LEFT JOIN order_forms f ON s.form_id = f.id
        LEFT JOIN products p ON s.product_id = p.id
        $where_sql
        ORDER BY s.created_at DESC
        LIMIT :limit OFFSET :offset
    ";
    
    $stmt = $conn->prepare($sql);
    foreach ($params as $key => $value) {
        $stmt->bindValue($key, $value);
    }
    $stmt->bindValue(':limit', $per_page, PDO::PARAM_INT);
    $stmt->bindValue(':offset', $offset, PDO::PARAM_INT);
    $stmt->execute();
    
    $submissions = $stmt->fetchAll();
    
    // Calculate pagination info
    $total_pages = ceil($total_submissions / $per_page);
    
} catch (PDOException $e) {
    $_SESSION['error_message'] = 'Fehler beim Laden der Bestellungen: ' . $e->getMessage();
    $submissions = [];
    $total_submissions = 0;
    $total_pages = 0;
}

// Get all forms for filter dropdown
try {
    $stmt = $conn->prepare("SELECT id, title FROM order_forms ORDER BY title");
    $stmt->execute();
    $all_forms = $stmt->fetchAll();
} catch (PDOException $e) {
    $_SESSION['error_message'] = 'Fehler beim Laden der Formulare: ' . $e->getMessage();
    $all_forms = [];
}

// Include header
$pageTitle = ($form_id > 0 && isset($form)) ? "Bestellungen: " . htmlspecialchars($form['title']) : "Alle Bestellungen";
include('includes/header.php');
?>

<div class="content-header">
    <h2><?php echo $pageTitle; ?></h2>
    <div class="content-header-actions">
        <a href="order_forms.php" class="btn btn-secondary">
            <i class="fas fa-clipboard-list"></i> Formulare verwalten
        </a>
    </div>
</div>

<div class="card">
    <div class="card-header">
        <h3>Filter</h3>
    </div>
    <div class="card-body">
        <form method="get" class="filter-form">
            <?php if ($form_id > 0): ?>
                <input type="hidden" name="form_id" value="<?php echo $form_id; ?>">
            <?php endif; ?>
            
            <div class="row">
                <?php if ($form_id === 0): ?>
                    <div class="col-md-3">
                        <div class="form-group">
                            <label for="form_filter">Formular</label>
                            <select id="form_filter" name="form_id" class="form-control">
                                <option value="0">Alle Formulare</option>
                                <?php foreach ($all_forms as $f): ?>
                                    <option value="<?php echo $f['id']; ?>" <?php echo ($form_id == $f['id']) ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($f['title']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                    </div>
                <?php endif; ?>
                
                <div class="col-md-3">
                    <div class="form-group">
                        <label for="processed_filter">Status</label>
                        <select id="processed_filter" name="processed" class="form-control">
                            <option value="all" <?php echo ($processed_filter === 'all') ? 'selected' : ''; ?>>Alle</option>
                            <option value="no" <?php echo ($processed_filter === 'no') ? 'selected' : ''; ?>>Unbearbeitet</option>
                            <option value="yes" <?php echo ($processed_filter === 'yes') ? 'selected' : ''; ?>>Bearbeitet</option>
                        </select>
                    </div>
                </div>
                
                <div class="col-md-3">
                    <div class="form-group">
                        <label for="search">Suche (Name oder E-Mail)</label>
                        <input type="text" id="search" name="search" class="form-control" value="<?php echo htmlspecialchars($search); ?>">
                    </div>
                </div>
                
                <div class="col-md-3">
                    <div class="form-group">
                        <label for="start_date">Von Datum</label>
                        <input type="date" id="start_date" name="start_date" class="form-control" value="<?php echo $start_date; ?>">
                    </div>
                </div>
                
                <div class="col-md-3">
                    <div class="form-group">
                        <label for="end_date">Bis Datum</label>
                        <input type="date" id="end_date" name="end_date" class="form-control" value="<?php echo $end_date; ?>">
                    </div>
                </div>
                
                <div class="col-md-3">
                    <div class="form-group" style="margin-top: 32px;">
                        <button type="submit" class="btn btn-primary">
                            <i class="fas fa-filter"></i> Filtern
                        </button>
                        <a href="order_submissions.php<?php echo $form_id > 0 ? '?form_id=' . $form_id : ''; ?>" class="btn btn-secondary">
                            <i class="fas fa-times"></i> Zurücksetzen
                        </a>
                    </div>
                </div>
            </div>
        </form>
    </div>
</div>

<div class="card mt-4">
    <div class="card-body">
        <?php if (count($submissions) > 0): ?>
            <div class="table-responsive">
                <table class="admin-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <?php if ($form_id === 0): ?>
                                <th>Formular</th>
                            <?php endif; ?>
                            <th>Produkt</th>
                            <th>Name</th>
                            <th>E-Mail</th>
                            <th>Datum</th>
                            <th>Status</th>
                            <th>Aktionen</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($submissions as $submission): ?>
                            <tr>
                                <td><?php echo $submission['id']; ?></td>
                                <?php if ($form_id === 0): ?>
                                    <td><?php echo htmlspecialchars($submission['form_title']); ?></td>
                                <?php endif; ?>
                                <td><?php echo $submission['product_name'] ? htmlspecialchars($submission['product_name']) : '-'; ?></td>
                                <td><?php echo htmlspecialchars($submission['customer_name']); ?></td>
                                <td><?php echo htmlspecialchars($submission['customer_email']); ?></td>
                                <td><?php echo date('d.m.Y H:i', strtotime($submission['created_at'])); ?></td>
                                <td>
                                    <form method="post" style="display: inline;" class="status-form">
                                        <input type="hidden" name="submission_id" value="<?php echo $submission['id']; ?>">
                                        <input type="hidden" name="processed" value="<?php echo $submission['processed'] ? '0' : '1'; ?>">
                                        <input type="hidden" name="mark_processed" value="1">
                                        <button type="button" class="btn btn-sm status-toggle <?php echo $submission['processed'] ? 'btn-success' : 'btn-warning'; ?>" 
                                               data-current="<?php echo $submission['processed'] ? 'bearbeitet' : 'unbearbeitet'; ?>"
                                               data-toggle="<?php echo $submission['processed'] ? 'unbearbeitet' : 'bearbeitet'; ?>">
                                            <?php echo $submission['processed'] ? 'Bearbeitet' : 'Unbearbeitet'; ?>
                                        </button>
                                    </form>
                                </td>
                                <td class="actions">
                                    <button type="button" class="btn btn-sm btn-info view-details" data-id="<?php echo $submission['id']; ?>">
                                        <i class="fas fa-eye"></i>
                                    </button>
                                    <form method="post" style="display: inline;" class="delete-form">
                                        <input type="hidden" name="submission_id" value="<?php echo $submission['id']; ?>">
                                        <button type="button" class="btn btn-sm btn-danger delete-btn">
                                            <i class="fas fa-trash-alt"></i>
                                        </button>
                                    </form>
                                </td>
                            </tr>
                            <!-- Hidden details row -->
                            <tr class="submission-details" id="details-<?php echo $submission['id']; ?>" style="display: none;">
                                <td colspan="<?php echo $form_id === 0 ? '8' : '7'; ?>">
                                    <div class="submission-data">
                                        <h4>Bestelldaten</h4>
                                        <?php 
                                        $data = json_decode($submission['submission_data'], true);
                                        if ($data && is_array($data)):
                                        ?>
                                            <table class="table table-sm">
                                                <tbody>
                                                    <?php foreach ($data as $key => $value): ?>
                                                        <tr>
                                                            <th><?php 
                                                            // Benutzerfreundlichere Schlüsseldarstellung
                                                            $displayKey = $key;
                                                            switch($key) {
                                                                case 'customer_name':
                                                                    $displayKey = 'Name';
                                                                    break;
                                                                case 'customer_email':
                                                                    $displayKey = 'E-Mail';
                                                                    break;
                                                                case 'customer_address':
                                                                    $displayKey = 'Adresse';
                                                                    break;
                                                                case 'customer_phone':
                                                                    $displayKey = 'Telefon';
                                                                    break;
                                                                case 'customer_message':
                                                                    $displayKey = 'Nachricht';
                                                                    break;
                                                                default:
                                                                    // Entferne "customer_" Präfix falls vorhanden
                                                                    if (strpos($key, 'customer_') === 0) {
                                                                        $displayKey = ucfirst(substr($key, 9));
                                                                    } else {
                                                                        // Erste Buchstabe groß
                                                                        $displayKey = ucfirst($key);
                                                                    }
                                                            }
                                                            echo htmlspecialchars($displayKey); 
                                                            ?></th>
                                                            <td>
                                                                <?php 
                                                                if (is_array($value)) {
                                                                    echo implode(', ', array_map('htmlspecialchars', $value));
                                                                } else {
                                                                    echo htmlspecialchars($value);
                                                                }
                                                                ?>
                                                            </td>
                                                        </tr>
                                                    <?php endforeach; ?>
                                                </tbody>
                                            </table>
                                        <?php else: ?>
                                            <div class="alert alert-info">Keine strukturierten Daten verfügbar.</div>
                                        <?php endif; ?>
                                    </div>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
            
            <!-- Pagination -->
            <?php if ($total_pages > 1): ?>
                <nav aria-label="Bestellungen Navigation">
                    <ul class="pagination justify-content-center">
                        <?php if ($current_page > 1): ?>
                            <li class="page-item">
                                <a class="page-link" href="?page=<?php echo $current_page - 1; ?><?php echo isset($_GET['form_id']) ? '&form_id=' . intval($_GET['form_id']) : ''; ?><?php echo isset($_GET['processed']) ? '&processed=' . htmlspecialchars($_GET['processed']) : ''; ?><?php echo !empty($search) ? '&search=' . urlencode($search) : ''; ?><?php echo !empty($start_date) ? '&start_date=' . urlencode($start_date) : ''; ?><?php echo !empty($end_date) ? '&end_date=' . urlencode($end_date) : ''; ?>">
                                    Vorherige
                                </a>
                            </li>
                        <?php endif; ?>
                        
                        <?php 
                        $start_page = max(1, $current_page - 2);
                        $end_page = min($total_pages, $current_page + 2);
                        
                        for ($i = $start_page; $i <= $end_page; $i++): 
                        ?>
                            <li class="page-item <?php echo ($i == $current_page) ? 'active' : ''; ?>">
                                <a class="page-link" href="?page=<?php echo $i; ?><?php echo isset($_GET['form_id']) ? '&form_id=' . intval($_GET['form_id']) : ''; ?><?php echo isset($_GET['processed']) ? '&processed=' . htmlspecialchars($_GET['processed']) : ''; ?><?php echo !empty($search) ? '&search=' . urlencode($search) : ''; ?><?php echo !empty($start_date) ? '&start_date=' . urlencode($start_date) : ''; ?><?php echo !empty($end_date) ? '&end_date=' . urlencode($end_date) : ''; ?>">
                                    <?php echo $i; ?>
                                </a>
                            </li>
                        <?php endfor; ?>
                        
                        <?php if ($current_page < $total_pages): ?>
                            <li class="page-item">
                                <a class="page-link" href="?page=<?php echo $current_page + 1; ?><?php echo isset($_GET['form_id']) ? '&form_id=' . intval($_GET['form_id']) : ''; ?><?php echo isset($_GET['processed']) ? '&processed=' . htmlspecialchars($_GET['processed']) : ''; ?><?php echo !empty($search) ? '&search=' . urlencode($search) : ''; ?><?php echo !empty($start_date) ? '&start_date=' . urlencode($start_date) : ''; ?><?php echo !empty($end_date) ? '&end_date=' . urlencode($end_date) : ''; ?>">
                                    Nächste
                                </a>
                            </li>
                        <?php endif; ?>
                    </ul>
                </nav>
            <?php endif; ?>
            
            <div class="submission-count text-center mt-3">
                <p>
                    Zeige <?php echo ($offset + 1); ?> bis <?php echo min($offset + count($submissions), $total_submissions); ?> 
                    von <?php echo $total_submissions; ?> Bestellungen
                </p>
            </div>
            
        <?php else: ?>
            <div class="alert alert-info">
                <i class="fas fa-info-circle"></i> Keine Bestellungen gefunden.
                <?php if (!empty($search) || $processed_filter !== 'all' || !empty($start_date) || !empty($end_date)): ?>
                    Versuchen Sie, die Filter anzupassen.
                <?php endif; ?>
            </div>
        <?php endif; ?>
    </div>
</div>

<script>
document.addEventListener('DOMContentLoaded', function() {
    // View details button
    document.querySelectorAll('.view-details').forEach(button => {
        button.addEventListener('click', function() {
            const id = this.dataset.id;
            const detailsRow = document.getElementById('details-' + id);
            
            if (detailsRow.style.display === 'none' || !detailsRow.style.display) {
                // Hide all other details first
                document.querySelectorAll('.submission-details').forEach(row => {
                    row.style.display = 'none';
                });
                
                // Show this one
                detailsRow.style.display = 'table-row';
                this.innerHTML = '<i class="fas fa-chevron-up"></i>';
            } else {
                detailsRow.style.display = 'none';
                this.innerHTML = '<i class="fas fa-eye"></i>';
            }
        });
    });
    
    // Status toggle buttons (Bearbeitet/Unbearbeitet) mit Bestätigung
    document.querySelectorAll('.status-toggle').forEach(button => {
        button.addEventListener('click', function() {
            const currentStatus = this.getAttribute('data-current');
            const newStatus = this.getAttribute('data-toggle');
            
            if (confirm(`Möchten Sie den Status wirklich von "${currentStatus}" zu "${newStatus}" ändern?`)) {
                // Bei Bestätigung das Formular absenden
                this.closest('form').submit();
            }
        });
    });
    
    // Lösch-Buttons mit Bestätigung
    document.querySelectorAll('.delete-btn').forEach(button => {
        button.addEventListener('click', function() {
            if (confirm('Möchten Sie diese Bestellung wirklich löschen? Dieser Vorgang kann nicht rückgängig gemacht werden.')) {
                // Bei Bestätigung das Formular absenden
                const form = this.closest('form');
                const submitButton = document.createElement('input');
                submitButton.type = 'hidden';
                submitButton.name = 'delete_submission';
                submitButton.value = '1';
                form.appendChild(submitButton);
                form.submit();
            }
        });
    });
});
</script>

<style>
.submission-data {
    padding: 15px;
    background-color: #f8f9fa;
    border-radius: 4px;
}

.filter-form .btn {
    margin-right: 10px;
}
</style>

<?php include('includes/footer.php'); ?>