<?php
session_start();
require_once('../includes/db_connect.php');

// Überprüfen, ob der Benutzer angemeldet ist
if (!isset($_SESSION['admin_logged_in']) || $_SESSION['admin_logged_in'] !== true) {
    header('Location: index.php');
    exit;
}

// Tabelle für Popups erstellen, falls sie noch nicht existiert
try {
    $conn->exec("CREATE TABLE IF NOT EXISTS popups (
        id INTEGER PRIMARY KEY AUTOINCREMENT,
        title TEXT NOT NULL,
        content TEXT NOT NULL,
        type TEXT DEFAULT 'info',
        active INTEGER DEFAULT 1,
        start_date TEXT,
        end_date TEXT,
        created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
        updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP
    )");
} catch (PDOException $e) {
    error_log("Fehler beim Erstellen der Popup-Tabelle: " . $e->getMessage());
}

// Popup löschen
if (isset($_GET['delete']) && is_numeric($_GET['delete'])) {
    try {
        $stmt = $conn->prepare("DELETE FROM popups WHERE id = ?");
        $stmt->execute([$_GET['delete']]);
        $_SESSION['success_message'] = "Popup wurde erfolgreich gelöscht.";
    } catch (PDOException $e) {
        $_SESSION['error_message'] = "Fehler beim Löschen des Popups.";
        error_log("Fehler beim Löschen: " . $e->getMessage());
    }
    header("Location: popups.php");
    exit;
}

// Popup-Status ändern (aktivieren/deaktivieren)
if (isset($_GET['toggle']) && is_numeric($_GET['toggle'])) {
    try {
        $stmt = $conn->prepare("SELECT active FROM popups WHERE id = ?");
        $stmt->execute([$_GET['toggle']]);
        $currentStatus = $stmt->fetchColumn();
        
        $newStatus = $currentStatus ? 0 : 1;
        
        $stmt = $conn->prepare("UPDATE popups SET active = ? WHERE id = ?");
        $stmt->execute([$newStatus, $_GET['toggle']]);
        
        $_SESSION['success_message'] = "Status des Popups wurde geändert.";
    } catch (PDOException $e) {
        $_SESSION['error_message'] = "Fehler beim Ändern des Popup-Status.";
        error_log("Fehler beim Statusändern: " . $e->getMessage());
    }
    header("Location: popups.php");
    exit;
}

// Popup erstellen oder bearbeiten
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['save_popup'])) {
    $title = trim($_POST['title']);
    $content = trim($_POST['content']);
    $type = $_POST['type'];
    $active = isset($_POST['active']) ? 1 : 0;
    $start_date = !empty($_POST['start_date']) ? $_POST['start_date'] : null;
    $end_date = !empty($_POST['end_date']) ? $_POST['end_date'] : null;
    
    // Validierung
    if (empty($title) || empty($content)) {
        $_SESSION['error_message'] = "Titel und Inhalt sind erforderlich.";
    } else {
        try {
            if (isset($_POST['popup_id']) && is_numeric($_POST['popup_id'])) {
                // Popup aktualisieren
                $stmt = $conn->prepare("UPDATE popups SET 
                    title = ?, 
                    content = ?, 
                    type = ?, 
                    active = ?,
                    start_date = ?,
                    end_date = ?,
                    updated_at = CURRENT_TIMESTAMP
                    WHERE id = ?");
                $stmt->execute([$title, $content, $type, $active, $start_date, $end_date, $_POST['popup_id']]);
                $_SESSION['success_message'] = "Popup wurde erfolgreich aktualisiert.";
            } else {
                // Neues Popup erstellen
                $stmt = $conn->prepare("INSERT INTO popups (title, content, type, active, start_date, end_date) 
                    VALUES (?, ?, ?, ?, ?, ?)");
                $stmt->execute([$title, $content, $type, $active, $start_date, $end_date]);
                $_SESSION['success_message'] = "Popup wurde erfolgreich erstellt.";
            }
        } catch (PDOException $e) {
            $_SESSION['error_message'] = "Fehler beim Speichern des Popups.";
            error_log("Fehler beim Speichern: " . $e->getMessage());
        }
        header("Location: popups.php");
        exit;
    }
}

// Popup zum Bearbeiten laden
$editPopup = null;
if (isset($_GET['edit']) && is_numeric($_GET['edit'])) {
    try {
        $stmt = $conn->prepare("SELECT * FROM popups WHERE id = ?");
        $stmt->execute([$_GET['edit']]);
        $editPopup = $stmt->fetch();
    } catch (PDOException $e) {
        error_log("Fehler beim Laden des Popups: " . $e->getMessage());
    }
}

// Alle Popups laden
$popups = [];
try {
    $stmt = $conn->query("SELECT * FROM popups ORDER BY created_at DESC");
    $popups = $stmt->fetchAll();
} catch (PDOException $e) {
    error_log("Fehler beim Laden der Popups: " . $e->getMessage());
}

// Seitentitel setzen und Header einfügen
$pageTitle = "Popups verwalten";
include('includes/header.php');
?>

<div class="content-container">
    <div class="card mb-4">
        <div class="card-header">
            <h3><?php echo $editPopup ? 'Popup bearbeiten' : 'Neues Popup erstellen'; ?></h3>
        </div>
        <div class="card-body">
            <form action="popups.php" method="post">
                <input type="hidden" name="save_popup" value="1">
                <?php if ($editPopup): ?>
                    <input type="hidden" name="popup_id" value="<?php echo $editPopup['id']; ?>">
                <?php endif; ?>
                
                <div class="form-group">
                    <label for="title">Titel</label>
                    <input type="text" id="title" name="title" class="form-control" 
                           value="<?php echo $editPopup ? htmlspecialchars($editPopup['title']) : ''; ?>" required>
                </div>
                
                <div class="form-group">
                    <label for="content">Inhalt</label>
                    <textarea id="content" name="content" class="form-control" rows="4" required><?php 
                        echo $editPopup ? htmlspecialchars($editPopup['content']) : ''; 
                    ?></textarea>
                    <small class="form-text text-muted">Sie können HTML-Tags für die Formatierung verwenden.</small>
                </div>
                
                <div class="form-group">
                    <label for="type">Typ</label>
                    <select id="type" name="type" class="form-control">
                        <option value="info" <?php echo ($editPopup && $editPopup['type'] == 'info') ? 'selected' : ''; ?>>
                            Information
                        </option>
                        <option value="warning" <?php echo ($editPopup && $editPopup['type'] == 'warning') ? 'selected' : ''; ?>>
                            Warnung
                        </option>
                        <option value="success" <?php echo ($editPopup && $editPopup['type'] == 'success') ? 'selected' : ''; ?>>
                            Erfolg
                        </option>
                        <option value="promo" <?php echo ($editPopup && $editPopup['type'] == 'promo') ? 'selected' : ''; ?>>
                            Angebot/Aktion
                        </option>
                    </select>
                </div>
                
                <div class="form-row">
                    <div class="form-group col-md-6">
                        <label for="start_date">Startdatum (optional)</label>
                        <input type="date" id="start_date" name="start_date" class="form-control" 
                               value="<?php echo $editPopup && $editPopup['start_date'] ? $editPopup['start_date'] : ''; ?>">
                        <small class="form-text text-muted">Leer lassen für sofortige Anzeige</small>
                    </div>
                    
                    <div class="form-group col-md-6">
                        <label for="end_date">Enddatum (optional)</label>
                        <input type="date" id="end_date" name="end_date" class="form-control" 
                               value="<?php echo $editPopup && $editPopup['end_date'] ? $editPopup['end_date'] : ''; ?>">
                        <small class="form-text text-muted">Leer lassen für unbegrenzte Anzeige</small>
                    </div>
                </div>
                
                <div class="form-group form-check">
                    <input type="checkbox" id="active" name="active" class="form-check-input" 
                           <?php echo (!$editPopup || $editPopup['active']) ? 'checked' : ''; ?>>
                    <label class="form-check-label" for="active">Popup aktivieren</label>
                </div>
                
                <div class="form-group">
                    <button type="submit" class="btn btn-primary">Speichern</button>
                    <a href="popups.php" class="btn btn-outline-secondary">Abbrechen</a>
                </div>
            </form>
        </div>
    </div>
    
    <div class="card">
        <div class="card-header">
            <h3>Vorhandene Popups</h3>
        </div>
        <div class="card-body">
            <?php if (empty($popups)): ?>
                <p class="text-muted">Keine Popups vorhanden.</p>
            <?php else: ?>
                <div class="table-responsive">
                    <table class="table table-striped">
                        <thead>
                            <tr>
                                <th>Titel</th>
                                <th>Typ</th>
                                <th>Status</th>
                                <th>Zeitraum</th>
                                <th>Aktionen</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($popups as $popup): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($popup['title']); ?></td>
                                    <td>
                                        <?php 
                                        $typeLabels = [
                                            'info' => '<span class="badge badge-info">Information</span>',
                                            'warning' => '<span class="badge badge-warning">Warnung</span>',
                                            'success' => '<span class="badge badge-success">Erfolg</span>',
                                            'promo' => '<span class="badge badge-primary">Angebot</span>'
                                        ];
                                        echo $typeLabels[$popup['type']] ?? $popup['type'];
                                        ?>
                                    </td>
                                    <td>
                                        <?php if ($popup['active']): ?>
                                            <span class="badge badge-success">Aktiv</span>
                                        <?php else: ?>
                                            <span class="badge badge-secondary">Inaktiv</span>
                                        <?php endif; ?>
                                    </td>
                                    <td>
                                        <?php 
                                        $dateInfo = [];
                                        if ($popup['start_date']) {
                                            $dateInfo[] = 'Von: ' . $popup['start_date'];
                                        }
                                        if ($popup['end_date']) {
                                            $dateInfo[] = 'Bis: ' . $popup['end_date'];
                                        }
                                        echo !empty($dateInfo) ? implode('<br>', $dateInfo) : 'Unbegrenzt';
                                        ?>
                                    </td>
                                    <td>
                                        <div class="btn-group btn-group-sm">
                                            <a href="popups.php?edit=<?php echo $popup['id']; ?>" class="btn btn-primary">
                                                <i class="fas fa-edit"></i>
                                            </a>
                                            <a href="popups.php?toggle=<?php echo $popup['id']; ?>" class="btn btn-info">
                                                <?php if ($popup['active']): ?>
                                                    <i class="fas fa-toggle-off"></i>
                                                <?php else: ?>
                                                    <i class="fas fa-toggle-on"></i>
                                                <?php endif; ?>
                                            </a>
                                            <a href="popups.php?delete=<?php echo $popup['id']; ?>" 
                                               class="btn btn-danger" 
                                               onclick="return confirm('Sind Sie sicher, dass Sie dieses Popup löschen möchten?');">
                                                <i class="fas fa-trash"></i>
                                            </a>
                                        </div>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>
            <?php endif; ?>
        </div>
    </div>
</div>

<script>
document.addEventListener('DOMContentLoaded', function() {
    // Beispielvorschau erstellen
    const titleInput = document.getElementById('title');
    const contentInput = document.getElementById('content');
    const typeSelect = document.getElementById('type');
    
    // Hier könnte man eine Live-Vorschau implementieren, wenn gewünscht
});
</script>

<?php include('includes/footer.php'); ?> 