<?php
session_start();
require_once('../includes/db_connect.php');

// Überprüfen, ob der Benutzer angemeldet ist
if (!isset($_SESSION['admin_logged_in']) || $_SESSION['admin_logged_in'] !== true) {
    header('Location: index.php');
    exit;
}

// Admin-ID aus der Session holen
$adminId = $_SESSION['admin_id'];

// Admin-Benutzer aus der Datenbank abrufen
$stmt = $conn->prepare("SELECT * FROM admin_users WHERE id = ?");
$stmt->execute([$adminId]);
$user = $stmt->fetch();

$passwordChanged = false;
$usernameChanged = false;
$colorSchemeChanged = false;
$error = '';

// Formular für Passwortänderung verarbeiten
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['change_password'])) {
    $currentPassword = $_POST['current_password'];
    $newPassword = $_POST['new_password'];
    $confirmPassword = $_POST['confirm_password'];
    
    // Überprüfen, ob aktuelles Passwort stimmt
    if (!password_verify($currentPassword, $user['password_hash'])) {
        $_SESSION['error_message'] = "Das aktuelle Passwort ist nicht korrekt.";
    } elseif (strlen($newPassword) < 8) {
        $_SESSION['error_message'] = "Das neue Passwort muss mindestens 8 Zeichen lang sein.";
    } elseif ($newPassword !== $confirmPassword) {
        $_SESSION['error_message'] = "Die neuen Passwörter stimmen nicht überein.";
    } else {
        // Passwort aktualisieren
        $passwordHash = password_hash($newPassword, PASSWORD_DEFAULT);
        $stmt = $conn->prepare("UPDATE admin_users SET password_hash = ? WHERE id = ?");
        $stmt->execute([$passwordHash, $adminId]);
        
        $_SESSION['success_message'] = "Passwort wurde erfolgreich geändert.";
        $passwordChanged = true;
    }
}

// Formular für Benutzernamenänderung verarbeiten
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['change_username'])) {
    $newUsername = trim($_POST['new_username']);
    $password = $_POST['password'];
    
    // Überprüfen, ob das Passwort stimmt
    if (!password_verify($password, $user['password_hash'])) {
        $_SESSION['error_message'] = "Das eingegebene Passwort ist nicht korrekt.";
    } elseif (empty($newUsername) || strlen($newUsername) < 3) {
        $_SESSION['error_message'] = "Der neue Benutzername muss mindestens 3 Zeichen lang sein.";
    } else {
        // Prüfen, ob der Benutzername bereits existiert
        $stmt = $conn->prepare("SELECT COUNT(*) FROM admin_users WHERE username = ? AND id != ?");
        $stmt->execute([$newUsername, $adminId]);
        if ($stmt->fetchColumn() > 0) {
            $_SESSION['error_message'] = "Der Benutzername ist bereits vergeben.";
        } else {
            // Benutzernamen aktualisieren
            $stmt = $conn->prepare("UPDATE admin_users SET username = ? WHERE id = ?");
            $stmt->execute([$newUsername, $adminId]);
            
            $_SESSION['admin_username'] = $newUsername;
            $_SESSION['success_message'] = "Benutzername wurde erfolgreich geändert.";
            $usernameChanged = true;
        }
    }
}

// Formular für Farbschemaänderung verarbeiten
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['change_colors'])) {
    $primaryColor = $_POST['primary_color'];
    $secondaryColor = $_POST['secondary_color'];
    $accentColor = $_POST['accent_color'];
    
    // Überprüfen, ob die Farben im hexadezimalen Format sind
    if (!preg_match('/^#[a-fA-F0-9]{6}$/', $primaryColor) || 
        !preg_match('/^#[a-fA-F0-9]{6}$/', $secondaryColor) || 
        !preg_match('/^#[a-fA-F0-9]{6}$/', $accentColor)) {
        $_SESSION['error_message'] = "Bitte geben Sie gültige Farbwerte im Hex-Format ein (z.B. #ff0000).";
    } else {
        // Überprüfen, ob die Tabelle existiert, sonst erstellen
        $tableExists = tableExists('site_settings');
        if (!$tableExists) {
            $conn->exec("CREATE TABLE site_settings (
                id INT PRIMARY KEY AUTO_INCREMENT,
                setting_name VARCHAR(255) UNIQUE,
                setting_value TEXT,
                updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
            )");
        }
        
        // Farbwerte speichern
        $colors = [
            'primary_color' => $primaryColor,
            'secondary_color' => $secondaryColor,
            'accent_color' => $accentColor
        ];
        
        foreach ($colors as $name => $value) {
            $stmt = $conn->prepare("INSERT INTO site_settings (setting_name, setting_value) VALUES (?, ?) 
                                  ON DUPLICATE KEY UPDATE setting_value = VALUES(setting_value)");
            $stmt->execute([$name, $value]);
        }
        
        $_SESSION['success_message'] = "Farbschema wurde erfolgreich aktualisiert.";
        $colorSchemeChanged = true;
    }
}

// Aktuelle Farbwerte abrufen
$colors = [
    'primary_color' => '#8b6b4f',
    'secondary_color' => '#333333',
    'accent_color' => '#d4af37'
];

try {
    $stmt = $conn->query("SELECT setting_name, setting_value FROM site_settings WHERE setting_name IN ('primary_color', 'secondary_color', 'accent_color')");
    $savedColors = $stmt->fetchAll(PDO::FETCH_KEY_PAIR);

    foreach ($colors as $name => $defaultValue) {
        if (isset($savedColors[$name]) && !empty($savedColors[$name])) {
            $colors[$name] = $savedColors[$name];
        }
    }
} catch (PDOException $e) {
    error_log("Fehler beim Laden der Farbkonfiguration: " . $e->getMessage());
    // Bei Fehlern bleiben wir bei den Standardwerten
}

// Seitentitel setzen und Header einfügen
$pageTitle = "Einstellungen";
include('includes/header.php');
?>

<div class="form-card">
    <h3>Farbschema anpassen</h3>
    
    <form action="settings.php" method="post" id="colorForm">
        <input type="hidden" name="change_colors" value="1">
        
        <div class="form-group">
            <label for="primary_color">Primärfarbe</label>
            <div class="color-picker-container">
                <input type="color" id="primary_color" name="primary_color" class="form-control color-picker" value="<?php echo htmlspecialchars($colors['primary_color']); ?>">
                <input type="text" class="form-control color-value" value="<?php echo htmlspecialchars($colors['primary_color']); ?>" readonly>
            </div>
            <small class="form-text text-muted">Hauptfarbe für Überschriften und wichtige Elemente (Standardwert: #8b6b4f)</small>
        </div>
        
        <div class="form-group">
            <label for="secondary_color">Sekundärfarbe</label>
            <div class="color-picker-container">
                <input type="color" id="secondary_color" name="secondary_color" class="form-control color-picker" value="<?php echo htmlspecialchars($colors['secondary_color']); ?>">
                <input type="text" class="form-control color-value" value="<?php echo htmlspecialchars($colors['secondary_color']); ?>" readonly>
            </div>
            <small class="form-text text-muted">Farbe für Text und sekundäre Elemente (Standardwert: #333333)</small>
        </div>
        
        <div class="form-group">
            <label for="accent_color">Akzentfarbe</label>
            <div class="color-picker-container">
                <input type="color" id="accent_color" name="accent_color" class="form-control color-picker" value="<?php echo htmlspecialchars($colors['accent_color']); ?>">
                <input type="text" class="form-control color-value" value="<?php echo htmlspecialchars($colors['accent_color']); ?>" readonly>
            </div>
            <small class="form-text text-muted">Farbe für Buttons und Hervorhebungen (Standardwert: #d4af37)</small>
        </div>
        
        <div class="form-group">
            <button type="submit" class="btn btn-primary">Farbschema speichern</button>
            <button type="button" id="resetColors" class="btn btn-outline-secondary">Auf Standardwerte zurücksetzen</button>
        </div>
    </form>
    
    <div class="color-preview">
        <h4>Vorschau</h4>
        <div class="preview-container">
            <div class="preview-header">
                <span class="preview-logo">JB Kerzen</span>
                <span class="preview-nav">Navigation</span>
            </div>
            <div class="preview-hero">
                <span class="preview-headline">Überschrift</span>
                <button class="preview-button">Button</button>
            </div>
            <div class="preview-text">
                <span class="preview-title">Sektionsüberschrift</span>
                <p class="preview-paragraph">Dies ist ein Beispieltext zur Vorschau der Farben.</p>
            </div>
        </div>
    </div>
</div>

<div class="form-card">
    <h3>Benutzername ändern</h3>
    
    <form action="settings.php" method="post" id="usernameForm">
        <input type="hidden" name="change_username" value="1">
        
        <div class="form-group">
            <label for="current_username">Aktueller Benutzername</label>
            <input type="text" id="current_username" class="form-control" value="<?php echo htmlspecialchars($_SESSION['admin_username']); ?>" readonly>
        </div>
        
        <div class="form-group">
            <label for="new_username">Neuer Benutzername</label>
            <input type="text" id="new_username" name="new_username" class="form-control" required minlength="3">
        </div>
        
        <div class="form-group">
            <label for="password">Passwort zur Bestätigung</label>
            <input type="password" id="password" name="password" class="form-control" required>
            <small class="form-text text-muted">Geben Sie Ihr aktuelles Passwort ein, um die Änderung zu bestätigen.</small>
        </div>
        
        <div class="form-group">
            <button type="submit" class="btn btn-primary">Benutzername ändern</button>
        </div>
    </form>
</div>

<div class="form-card">
    <h3>Passwort ändern</h3>
    
    <form action="settings.php" method="post" id="passwordForm">
        <input type="hidden" name="change_password" value="1">
        
        <div class="form-group">
            <label for="current_password">Aktuelles Passwort</label>
            <input type="password" id="current_password" name="current_password" class="form-control" required>
        </div>
        
        <div class="form-group">
            <label for="new_password">Neues Passwort</label>
            <input type="password" id="new_password" name="new_password" class="form-control" required minlength="8">
            <small class="form-text text-muted">Das Passwort muss mindestens 8 Zeichen lang sein.</small>
        </div>
        
        <div class="form-group">
            <label for="confirm_password">Neues Passwort bestätigen</label>
            <input type="password" id="confirm_password" name="confirm_password" class="form-control" required minlength="8">
        </div>
        
        <div class="form-group">
            <button type="submit" class="btn btn-primary">Passwort ändern</button>
        </div>
    </form>
</div>

<div class="form-card">
    <h3>Datenbankwartung</h3>
    
    <div class="alert alert-info">
        <i class="fas fa-info-circle"></i> MySQL-Datenbankverbindung: <code><?php echo htmlspecialchars(DB_HOST . "/" . DB_NAME); ?></code>
    </div>
    
    <div class="database-maintenance">
        <p>Die folgenden Optionen helfen Ihnen bei der Wartung Ihrer Datenbank:</p>
        
        <div class="maintenance-actions">
            <form action="maintenance.php" method="post" class="mb-3">
                <input type="hidden" name="action" value="optimize">
                <button type="submit" class="btn btn-secondary">
                    <i class="fas fa-database"></i> Datenbank optimieren
                </button>
                <small class="form-text text-muted">Optimiert die Datenbankstruktur und verbessert die Performance.</small>
            </form>
            
            <form action="maintenance.php" method="post" class="mb-3">
                <input type="hidden" name="action" value="backup">
                <button type="submit" class="btn btn-secondary">
                    <i class="fas fa-download"></i> Datenbank-Backup erstellen
                </button>
                <small class="form-text text-muted">Erstellt ein SQL-Backup der aktuellen Datenbank.</small>
            </form>
        </div>
    </div>
</div>

<script>
document.addEventListener('DOMContentLoaded', function() {
    // Passwort-Bestätigung Validierung
    const newPassword = document.getElementById('new_password');
    const confirmPassword = document.getElementById('confirm_password');
    
    function validatePassword() {
        if (newPassword.value !== confirmPassword.value) {
            confirmPassword.setCustomValidity('Die Passwörter stimmen nicht überein.');
        } else {
            confirmPassword.setCustomValidity('');
        }
    }
    
    newPassword.addEventListener('change', validatePassword);
    confirmPassword.addEventListener('keyup', validatePassword);
    
    // Color picker functionality
    const colorInputs = document.querySelectorAll('.color-picker');
    const defaultColors = {
        'primary_color': '#8b6b4f',
        'secondary_color': '#333333',
        'accent_color': '#d4af37'
    };
    
    colorInputs.forEach(input => {
        const valueInput = input.parentElement.querySelector('.color-value');
        
        input.addEventListener('input', function() {
            valueInput.value = this.value;
            updatePreview();
        });
    });
    
    // Reset colors to default
    document.getElementById('resetColors').addEventListener('click', function() {
        for (const [id, color] of Object.entries(defaultColors)) {
            const input = document.getElementById(id);
            const valueInput = input.parentElement.querySelector('.color-value');
            input.value = color;
            valueInput.value = color;
        }
        updatePreview();
    });
    
    // Update preview function
    function updatePreview() {
        const primaryColor = document.getElementById('primary_color').value;
        const secondaryColor = document.getElementById('secondary_color').value;
        const accentColor = document.getElementById('accent_color').value;
        
        const previewLogo = document.querySelector('.preview-logo');
        const previewTitle = document.querySelector('.preview-title');
        const previewNav = document.querySelector('.preview-nav');
        const previewParagraph = document.querySelector('.preview-paragraph');
        const previewButton = document.querySelector('.preview-button');
        const previewHeadline = document.querySelector('.preview-headline');
        
        previewLogo.style.color = primaryColor;
        previewTitle.style.color = primaryColor;
        previewNav.style.color = secondaryColor;
        previewParagraph.style.color = secondaryColor;
        previewButton.style.backgroundColor = accentColor;
        previewHeadline.style.color = primaryColor;
    }
    
    // Initial update
    updatePreview();
});
</script>

<?php include('includes/footer.php'); ?> 