<?php
require_once('includes/db_connect.php');
require_once('order_form_manager.php'); // Formular-Manager einbinden
require_once('includes/voucher_functions.php'); // Gutschein-Funktionen einbinden

// Session für Gutschein-Daten starten
session_start();

// AJAX-Handler müssen vor allen anderen Checks stehen!
// Gutschein-Validierung via AJAX
if (isset($_POST['action']) && $_POST['action'] === 'validate_voucher') {
    $code = $_POST['voucher_code'] ?? '';
    $orderTotal = floatval($_POST['order_total'] ?? 0);
    
    // Debug-Informationen loggen
    error_log("Gutschein-Validierung: Code='$code', OrderTotal=$orderTotal");
    
    try {
        $result = validateVoucher($conn, $code, $orderTotal);
        
        if ($result['success']) {
            // Gutschein in Session speichern
            $_SESSION['applied_voucher'] = [
                'code' => $result['voucher_data']['code'],
                'id' => $result['voucher_data']['id'],
                'discount_amount' => $result['discount_amount'],
                'description' => $result['voucher_data']['description']
            ];
            
            error_log("Gutschein erfolgreich angewendet: " . $result['voucher_data']['code']);
        } else {
            error_log("Gutschein-Validierung fehlgeschlagen: " . $result['message']);
        }
        
        header('Content-Type: application/json');
        echo json_encode($result);
        
    } catch (Exception $e) {
        error_log("Gutschein-Validierung Exception: " . $e->getMessage());
        
        header('Content-Type: application/json');
        echo json_encode([
            'success' => false,
            'message' => 'Technischer Fehler bei der Gutschein-Validierung: ' . $e->getMessage(),
            'voucher_data' => null
        ]);
    }
    
    exit;
}

// Gutschein entfernen
if (isset($_POST['action']) && $_POST['action'] === 'remove_voucher') {
    unset($_SESSION['applied_voucher']);
    header('Content-Type: application/json');
    echo json_encode(['success' => true]);
    exit;
}

// Jetzt erst die normalen Warenkorb-Checks
// Check if we have quantities data
if (!isset($_POST['quantities']) || !is_array($_POST['quantities'])) {
    error_log('order_cart.php: Keine Mengen-Daten gefunden');
    header('Location: order.php');
    exit;
}

// Filter out items with quantity 0
$quantities = array_filter($_POST['quantities'], function($qty) {
    return intval($qty) > 0;
});

// If no items with quantity > 0, go back to order page
if (empty($quantities)) {
    error_log('order_cart.php: Keine Produkte mit Menge > 0');
    header('Location: order.php');
    exit;
}

// Debug info about quantities
error_log('order_cart.php: Mengen nach Filterung: ' . print_r($quantities, true));

// Get products information
$productIds = array_keys($quantities);
$placeholders = implode(',', array_fill(0, count($productIds), '?'));

try {
    $stmt = $conn->prepare("
        SELECT p.*, 
               (SELECT id FROM order_forms WHERE product_id = p.id AND active = 1 LIMIT 1) as form_id 
        FROM products p 
        WHERE p.id IN ($placeholders) AND p.active = 1
    ");

    foreach ($productIds as $i => $id) {
        $stmt->bindValue($i + 1, $id);
    }

    $stmt->execute();
    $products = $stmt->fetchAll(PDO::FETCH_ASSOC);
    
    // Debug info about products
    error_log('order_cart.php: Gefundene Produkte: ' . count($products));
    foreach ($products as $product) {
        error_log('order_cart.php: Produkt #' . $product['id'] . ', Form ID: ' . ($product['form_id'] ?? 'keine'));
    }
    
    // Überprüfe, ob für jedes Produkt ein Formular gefunden wurde
    $missingForms = [];
    foreach ($products as $product) {
        if (empty($product['form_id'])) {
            $missingForms[] = $product['id'];
        }
    }
    
    if (!empty($missingForms)) {
        error_log('order_cart.php: Formulare fehlen für Produkte: ' . implode(', ', $missingForms));
    }
} catch (PDOException $e) {
    error_log('order_cart.php: Fehler beim Laden der Produkte: ' . $e->getMessage());
    // Fallback: Leere Produktliste
    $products = [];
}

// Get site title
$stmt = $conn->prepare("SELECT setting_value FROM site_settings WHERE setting_name = 'site_title'");
$stmt->execute();
$site_title = $stmt->fetchColumn() ?: 'JB Kerzen';

// Get brand info
$stmt = $conn->prepare("SELECT * FROM brand_info WHERE id = 1");
$stmt->execute();
$brand = $stmt->fetch();

// Get order logo
$stmt = $conn->prepare("SELECT setting_value FROM site_settings WHERE setting_name = 'order_logo'");
$stmt->execute();
$order_logo = $stmt->fetchColumn() ?: '';

// Get site colors for styling
try {
    $stmt = $conn->query("SELECT setting_name, setting_value FROM site_settings WHERE setting_name IN ('primary_color', 'secondary_color', 'accent_color')");
    $colors = $stmt->fetchAll(PDO::FETCH_KEY_PAIR);
} catch (PDOException $e) {
    // Use default colors if query fails
    $colors = [
        'primary_color' => '#8b6b4f',
        'secondary_color' => '#333333',
        'accent_color' => '#d4af37'
    ];
}

// If colors not found, use defaults
if (!isset($colors['primary_color'])) $colors['primary_color'] = '#8b6b4f';
if (!isset($colors['secondary_color'])) $colors['secondary_color'] = '#333333';
if (!isset($colors['accent_color'])) $colors['accent_color'] = '#d4af37';
?>
<!DOCTYPE html>
<html lang="de">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Warenkorb | <?php echo htmlspecialchars($site_title); ?></title>
    <link rel="stylesheet" href="assets/css/style.css">
    <link rel="stylesheet" href="assets/css/center-fix.css">
    <link rel="stylesheet" href="assets/css/order-forms.css">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css">
    <style>
        :root {
            --primary-color: <?php echo $colors['primary_color']; ?>;
            --secondary-color: <?php echo $colors['secondary_color']; ?>;
            --accent-color: <?php echo $colors['accent_color']; ?>;
        }
        
        body {
            font-family: 'Helvetica Neue', Arial, sans-serif;
            line-height: 1.6;
            color: #333;
            margin: 0;
            padding: 0;
            background-color: #f8f8f8;
        }
        
        .container {
            max-width: 1200px;
            margin: 0 auto;
            padding: 0 20px;
        }
        
        /* Row und Column Layout für Adressfelder */
        .row {
            display: flex;
            flex-wrap: wrap;
            margin-right: -15px;
            margin-left: -15px;
        }
        
        .col-md-4, .col-md-8 {
            position: relative;
            width: 100%;
            padding-right: 15px;
            padding-left: 15px;
        }
        
        @media (min-width: 768px) {
            .col-md-4 {
                flex: 0 0 33.333333%;
                max-width: 33.333333%;
            }
            
            .col-md-8 {
                flex: 0 0 66.666667%;
                max-width: 66.666667%;
            }
        }
        
        .section {
            padding: 60px 0;
        }
        
        .section-title {
            text-align: center;
            margin-bottom: 40px;
            font-size: 32px;
            color: var(--primary-color);
        }
        
        .cart-container {
            background: white;
            border-radius: 10px;
            box-shadow: 0 3px 15px rgba(0,0,0,0.1);
            padding: 30px;
            margin-bottom: 40px;
        }
        
        .cart-header {
            display: grid;
            grid-template-columns: 100px 1fr 120px 120px 120px 100px;
            gap: 15px;
            padding-bottom: 15px;
            border-bottom: 1px solid #eee;
            font-weight: bold;
        }
        
        .cart-item {
            display: grid;
            grid-template-columns: 100px 1fr 120px 120px 120px 100px;
            gap: 15px;
            padding: 20px 0;
            border-bottom: 1px solid #eee;
            align-items: center;
        }
        
        .cart-item-image {
            width: 80px;
            height: 80px;
            object-fit: contain;
        }
        
        .cart-item-title {
            font-weight: 500;
            color: var(--primary-color);
            margin: 0 0 5px 0;
        }
        
        .cart-item-desc {
            color: #666;
            font-size: 14px;
            margin: 0;
        }
        
        .cart-item-quantity {
            font-weight: bold;
        }
        
        .cart-item-remove {
            color: #dc3545;
            cursor: pointer;
            background: none;
            border: none;
            font-size: 18px;
        }
        
        .form-container {
            background: white;
            border-radius: 10px;
            box-shadow: 0 3px 15px rgba(0,0,0,0.1);
            padding: 30px;
        }
        
        .form-group {
            margin-bottom: 25px;
        }
        
        .form-group label {
            display: block;
            font-weight: 500;
            margin-bottom: 8px;
            color: var(--secondary-color);
        }
        
        .form-control {
            width: 100%;
            padding: 12px 15px;
            font-size: 16px;
            border: 1px solid #ddd;
            border-radius: 5px;
            transition: border-color 0.3s;
        }
        
        .form-control:focus {
            border-color: var(--primary-color);
            outline: none;
        }
        
        .btn {
            display: inline-block;
            background-color: var(--primary-color);
            color: white;
            font-size: 16px;
            font-weight: 500;
            padding: 12px 25px;
            border: none;
            border-radius: 5px;
            cursor: pointer;
            transition: background-color 0.3s;
            text-decoration: none;
        }
        
        .btn:hover {
            background-color: var(--accent-color);
        }
        
        .btn-link {
            background: none;
            color: var(--primary-color);
            text-decoration: underline;
            padding: 0;
            font-size: 16px;
            cursor: pointer;
            border: none;
        }
        
        .btn-link:hover {
            color: var(--accent-color);
        }
        
        .form-actions {
            margin-top: 30px;
            display: flex;
            justify-content: space-between;
            align-items: center;
        }
        
        .site-header {
            background-color: white;
            box-shadow: 0 2px 10px rgba(0,0,0,0.1);
            position: relative;
            z-index: 100;
            padding: 15px 0;
        }
        
        .header-content {
            display: flex;
            justify-content: space-between;
            align-items: center;
        }
        
        .brand-text {
            font-size: 24px;
            color: var(--primary-color);
            text-decoration: none;
            font-weight: bold;
        }
        
        .brand-logo {
            height: 60px;
            width: auto;
        }
        
        .back-link {
            color: var(--primary-color);
            text-decoration: none;
            display: flex;
            align-items: center;
            gap: 5px;
        }
        
        .back-link:hover {
            color: var(--accent-color);
        }
        
        .site-footer {
            background-color: var(--secondary-color);
            color: white;
            padding: 30px 0;
            margin-top: 50px;
        }
        
        .footer-content {
            display: flex;
            flex-direction: column;
            align-items: center;
            text-align: center;
        }
        
        .footer-copyright {
            margin-bottom: 15px;
        }
        
        .footer-links {
            display: flex;
            gap: 20px;
        }
        
        .footer-links a {
            color: white;
            text-decoration: none;
        }
        
        .footer-links a:hover {
            text-decoration: underline;
        }
        
        /* Order steps indicator */
        .order-steps {
            display: flex;
            justify-content: center;
            margin-bottom: 40px;
        }
        
        .step {
            display: flex;
            flex-direction: column;
            align-items: center;
            width: 150px;
            position: relative;
        }
        
        .step:not(:last-child)::after {
            content: '';
            position: absolute;
            top: 30px;
            right: -50%;
            width: 100%;
            height: 2px;
            background-color: #ddd;
            z-index: 1;
        }
        
        .step.active:not(:last-child)::after {
            background-color: var(--accent-color);
        }
        
        .step-number {
            width: 60px;
            height: 60px;
            border-radius: 50%;
            background-color: #ddd;
            display: flex;
            align-items: center;
            justify-content: center;
            font-size: 24px;
            font-weight: bold;
            color: white;
            margin-bottom: 10px;
            position: relative;
            z-index: 2;
        }
        
        .step.active .step-number {
            background-color: var(--accent-color);
        }
        
        .step.completed .step-number {
            background-color: #28a745;
        }
        
        .step-title {
            font-weight: 500;
            color: #777;
        }
        
        .step.active .step-title {
            color: var(--accent-color);
        }
        
        .step.completed .step-title {
            color: #28a745;
        }
        
        /* Required mark for form fields */
        .required-mark {
            color: #dc3545;
            margin-left: 3px;
        }
        
        /* Responsive adjustments */
        @media (max-width: 768px) {
            .cart-header {
                display: none;
            }
            
            .cart-item {
                grid-template-columns: 80px 1fr;
                grid-template-areas:
                    "image title"
                    "image price"
                    "image qty"
                    "image total"
                    "image remove";
                gap: 10px;
                padding: 15px 0;
            }
            
            .cart-item-image {
                grid-area: image;
            }
            
            .product-details {
                grid-area: title;
            }
            
            .item-price {
                grid-area: price;
                text-align: left;
            }
            
            .item-price::before {
                content: "Preis: ";
                font-weight: normal;
                color: #666;
            }
            
            .quantity-selection {
                grid-area: qty;
            }
            
            .item-total {
                grid-area: total;
                text-align: left;
            }
            
            .item-total::before {
                content: "Gesamt: ";
                font-weight: normal;
                color: #666;
            }
            
            .item-actions {
                grid-area: remove;
                justify-self: start;
            }
            
            .order-steps {
                flex-direction: column;
                align-items: center;
                gap: 20px;
            }
            
            .step {
                flex-direction: row;
                width: 100%;
                gap: 15px;
            }
            
            .step:not(:last-child)::after {
                display: none;
            }
            
            .step-number {
                width: 40px;
                height: 40px;
                font-size: 18px;
                margin-bottom: 0;
            }
            
            .form-actions {
                flex-direction: column;
                gap: 15px;
            }
            
            .btn {
                width: 100%;
            }
        }
        
        .customer-info {
            margin-top: 30px;
        }
        
        .quantity-selection {
            margin: 15px 0;
        }
        
        .quantity-controls {
            display: flex;
            align-items: center;
            margin-top: 5px;
        }
        
        .quantity-btn {
            width: 30px;
            height: 30px;
            border: 1px solid #ddd;
            background-color: #f8f8f8;
            font-weight: bold;
            cursor: pointer;
            display: flex;
            align-items: center;
            justify-content: center;
        }
        
        .quantity-btn:hover {
            background-color: #e9e9e9;
        }
        
        .quantity-input {
            width: 60px;
            height: 30px;
            border: 1px solid #ddd;
            text-align: center;
            margin: 0 5px;
        }
        
        .remove-btn {
            background-color: #f8d7da;
            border: 1px solid #f5c6cb;
            color: #721c24;
            padding: 5px 10px;
            border-radius: 4px;
            cursor: pointer;
            margin-top: 10px;
        }
        
        .remove-btn:hover {
            background-color: #f5c6cb;
        }
        
        .form-group {
            margin-bottom: 20px;
        }
        
        /* Neuer Stil für bedingte Pflichtfelder */
        .contact-required-mark {
            color: #dc3545;
            margin-left: 3px;
        }
        
        /* Optional: Hinzufügen eines speziellen Stils für das aktive Kontaktfeld */
        input:focus.contact-field-active {
            border-color: var(--accent-color);
            box-shadow: 0 0 0 0.2rem rgba(212, 175, 55, 0.25);
        }
        
        .item-price, .item-total {
            font-weight: bold;
            color: var(--accent-color);
            text-align: center;
        }
        
        .cart-total {
            margin-top: 20px;
            padding-top: 20px;
            border-top: 2px solid var(--primary-color);
            text-align: right;
        }
        
        .total-row {
            display: flex;
            justify-content: flex-end;
            align-items: center;
            gap: 20px;
            font-size: 1.2rem;
        }
        
        .total-label {
            font-weight: bold;
            color: var(--primary-color);
        }
        
        .total-amount {
            font-weight: bold;
            font-size: 1.4rem;
            color: var(--accent-color);
        }
        
        /* Gutschein-Styles */
        .voucher-section {
            margin: 20px 0;
            padding: 20px;
            background-color: #f8f9fa;
            border-radius: 8px;
            border: 1px solid #e9ecef;
        }
        
        .voucher-input-group {
            display: flex;
            gap: 10px;
            margin-bottom: 15px;
        }
        
        #voucher-code {
            flex: 1;
            padding: 10px;
            border: 1px solid #ddd;
            border-radius: 4px;
            font-size: 1rem;
            text-transform: uppercase;
        }
        
        .btn-voucher {
            background-color: var(--accent-color);
            color: white;
            border: none;
            padding: 10px 20px;
            border-radius: 4px;
            cursor: pointer;
            font-weight: bold;
            transition: background-color 0.3s;
        }
        
        .btn-voucher:hover {
            background-color: #b8941f;
        }
        
        .btn-voucher:disabled {
            background-color: #ccc;
            cursor: not-allowed;
        }
        
        .voucher-message {
            min-height: 20px;
            font-size: 0.9rem;
            margin-bottom: 10px;
        }
        
        .voucher-message.success {
            color: #28a745;
        }
        
        .voucher-message.error {
            color: #dc3545;
        }
        
        .applied-voucher {
            display: flex;
            align-items: center;
            justify-content: space-between;
            background-color: #d4edda;
            border: 1px solid #c3e6cb;
            border-radius: 4px;
            padding: 10px 15px;
            margin-top: 10px;
        }
        
        .voucher-info {
            display: flex;
            flex-direction: column;
            gap: 2px;
        }
        
        .voucher-code {
            font-weight: bold;
            color: #155724;
        }
        
        .voucher-description {
            font-size: 0.9rem;
            color: #155724;
        }
        
        .voucher-discount {
            font-weight: bold;
            color: #155724;
            font-size: 1.1rem;
        }
        
        .remove-voucher-btn {
            background: none;
            border: none;
            color: #155724;
            cursor: pointer;
            padding: 5px;
            border-radius: 50%;
            transition: background-color 0.3s;
        }
        
        .remove-voucher-btn:hover {
            background-color: rgba(21, 87, 36, 0.1);
        }
        
        .discount-row {
            color: #28a745 !important;
        }
        
        .discount-amount {
            color: #28a745 !important;
        }
        
        .final-total {
            border-top: 2px solid var(--primary-color);
            padding-top: 15px;
            margin-top: 15px;
            font-size: 1.3rem;
        }
        
        .final-total .total-amount {
            font-size: 1.6rem;
        }
    </style>
    <?php echo getFormStyles(); // Stile für die Produktformulare hinzufügen ?>
</head>
<body>
    <!-- Header -->
    <header class="site-header">
        <div class="container">
            <div class="header-content">
                <div class="brand">
                    <?php if (!empty($order_logo) && file_exists($order_logo)): ?>
                        <a href="index.php">
                            <img src="<?php echo htmlspecialchars($order_logo); ?>" alt="<?php echo htmlspecialchars($site_title); ?>" class="brand-logo">
                        </a>
                    <?php elseif (isset($brand['image_path']) && !empty($brand['image_path'])): ?>
                        <a href="index.php">
                            <img src="<?php echo htmlspecialchars($brand['image_path']); ?>" alt="<?php echo htmlspecialchars($brand['title'] ?? $site_title); ?>" class="brand-logo">
                        </a>
                    <?php else: ?>
                        <a href="index.php" class="brand-text">
                            <?php echo htmlspecialchars($brand['title'] ?? $site_title); ?>
                        </a>
                    <?php endif; ?>
                </div>
                
                <a href="order.php" class="back-link">
                    <i class="fas fa-arrow-left"></i> Zurück zur Produktauswahl
                </a>
            </div>
        </div>
    </header>
    
    <!-- Main Content -->
    <main>
        <section class="section">
            <div class="container">
                <h1 class="section-title">Warenkorb</h1>
                
                <?php if (isset($_GET['error'])): ?>
                <div style="margin: 20px auto; padding: 15px; border: 1px solid #f5c6cb; background-color: #f8d7da; color: #721c24; border-radius: 5px; max-width: 800px;">
                    <h3 style="margin-top: 0;">Es ist ein Fehler aufgetreten</h3>
                    <?php 
                    $errorCode = $_GET['error'];
                    $errorMessage = isset($_GET['message']) ? htmlspecialchars($_GET['message']) : '';
                    
                    switch ($errorCode) {
                        case 'missing_customer_data':
                            echo "<p>Bitte füllen Sie alle Pflichtfelder (Name, E-Mail, Adresse) aus.</p>";
                            break;
                        case 'no_products':
                            echo "<p>Keine Produkte in der Bestellung gefunden. Bitte wählen Sie Produkte aus.</p>";
                            break;
                        case 'db_error':
                            echo "<p>Datenbankfehler beim Speichern der Bestellung.</p>";
                            if (!empty($errorMessage)) {
                                echo "<p><small>Technische Details: $errorMessage</small></p>";
                            }
                            break;
                        case 'partial_success':
                            echo "<p>Ihre Bestellung konnte nur teilweise verarbeitet werden. Bitte versuchen Sie es erneut.</p>";
                            break;
                        default:
                            echo "<p>Ein unbekannter Fehler ist aufgetreten. Bitte versuchen Sie es erneut.</p>";
                            if (!empty($errorMessage)) {
                                echo "<p><small>Details: $errorMessage</small></p>";
                            }
                    }
                    ?>
                </div>
                <?php endif; ?>
                
                <!-- Steps indicator -->
                <div class="order-steps">
                    <div class="step completed">
                        <div class="step-number"><i class="fas fa-check"></i></div>
                        <div class="step-title">Produkte auswählen</div>
                    </div>
                    <div class="step active">
                        <div class="step-number">2</div>
                        <div class="step-title">Bestelldaten</div>
                    </div>
                    <div class="step">
                        <div class="step-number">3</div>
                        <div class="step-title">Bestätigung</div>
                    </div>
                </div>
                
                <div class="cart-container">
                    <div class="cart-header">
                        <div>Bild</div>
                        <div>Produkt</div>
                        <div>Einzelpreis</div>
                        <div>Anzahl</div>
                        <div>Gesamtpreis</div>
                        <div></div>
                    </div>
                    
                    <form method="post" action="process_order.php" id="orderForm">
                        <?php 
                        $hasError = false;
                        $totalPrice = 0;
                        $showTotalPrice = false;
                        foreach ($products as $product): 
                            $quantity = intval($quantities[$product['id']]);
                            $hasForm = !empty($product['form_id']);
                            $itemPrice = floatval($product['price']);
                            $itemTotal = $itemPrice * $quantity;
                            
                            if ($product['show_price']) {
                                $totalPrice += $itemTotal;
                                $showTotalPrice = true;
                            }
                            
                            // If a product doesn't have a form, mark as error
                            if (!$hasForm) {
                                $hasError = true;
                            }
                        ?>
                            <div class="cart-item" data-product-id="<?php echo $product['id']; ?>">
                                <img src="<?php echo htmlspecialchars($product['image_path']); ?>" alt="<?php echo htmlspecialchars($product['name']); ?>" class="cart-item-image">
                                
                                <div class="product-details">
                                    <h3>
                                        <?php echo htmlspecialchars($product['name']); ?>
                                        <input type="hidden" name="products[<?php echo $product['id']; ?>]" value="<?php echo $product['form_id']; ?>">
                                    </h3>
                                    <p><?php echo htmlspecialchars($product['short_description']); ?></p>
                                </div>
                                
                                <div class="item-price">
                                    <?php if ($product['show_price']): ?>
                                        <?php echo number_format($itemPrice, 2, ',', '.'); ?> €
                                    <?php else: ?>
                                        <span style="color: #999;">-</span>
                                    <?php endif; ?>
                                </div>
                                
                                <div class="quantity-selection">
                                    <div class="quantity-controls">
                                        <button type="button" class="quantity-btn minus" data-product-id="<?php echo $product['id']; ?>">-</button>
                                        <input type="number" id="quantity_<?php echo $product['id']; ?>" 
                                               name="quantities[<?php echo $product['id']; ?>]" min="1" 
                                               value="<?php echo intval($quantities[$product['id']]); ?>" 
                                               class="quantity-input" data-product-id="<?php echo $product['id']; ?>"
                                               data-price="<?php echo $itemPrice; ?>"
                                               data-show-price="<?php echo $product['show_price'] ? '1' : '0'; ?>">
                                        <button type="button" class="quantity-btn plus" data-product-id="<?php echo $product['id']; ?>">+</button>
                                    </div>
                                </div>
                                
                                <div class="item-total" data-product-id="<?php echo $product['id']; ?>">
                                    <?php if ($product['show_price']): ?>
                                        <?php echo number_format($itemTotal, 2, ',', '.'); ?> €
                                    <?php else: ?>
                                        <span style="color: #999;">-</span>
                                    <?php endif; ?>
                                </div>
                                
                                <div class="item-actions">
                                    <button type="button" class="remove-btn" data-product-id="<?php echo $product['id']; ?>">
                                        <i class="fas fa-trash"></i> Entfernen
                                    </button>
                                </div>
                            </div>
                        <?php endforeach; ?>
                        
                        <!-- Cart Total -->
                        <?php if ($showTotalPrice): ?>
                        <div class="cart-total">
                            <div class="total-row">
                                <span class="total-label">Zwischensumme:</span>
                                <span class="total-amount" id="cart-subtotal"><?php echo number_format($totalPrice, 2, ',', '.'); ?> €</span>
                            </div>
                            
                            <!-- Gutschein-Sektion -->
                            <div class="voucher-section">
                                <div class="voucher-input-group">
                                    <input type="text" id="voucher-code" placeholder="Gutscheincode eingeben" maxlength="50">
                                    <button type="button" id="apply-voucher-btn" class="btn-voucher">Einlösen</button>
                                </div>
                                <div id="voucher-message" class="voucher-message"></div>
                                
                                <!-- Angewendeter Gutschein -->
                                <?php if (isset($_SESSION['applied_voucher'])): ?>
                                <div id="applied-voucher" class="applied-voucher">
                                    <div class="voucher-info">
                                        <span class="voucher-code"><?php echo htmlspecialchars($_SESSION['applied_voucher']['code']); ?></span>
                                        <span class="voucher-description"><?php echo htmlspecialchars($_SESSION['applied_voucher']['description']); ?></span>
                                    </div>
                                    <div class="voucher-discount">
                                        -<?php echo number_format($_SESSION['applied_voucher']['discount_amount'], 2, ',', '.'); ?> €
                                    </div>
                                    <button type="button" id="remove-voucher-btn" class="remove-voucher-btn">
                                        <i class="fas fa-times"></i>
                                    </button>
                                </div>
                                <?php endif; ?>
                            </div>
                            
                            <!-- Rabatt-Zeile -->
                            <?php if (isset($_SESSION['applied_voucher'])): ?>
                            <div class="total-row discount-row">
                                <span class="total-label">Rabatt:</span>
                                <span class="total-amount discount-amount" id="cart-discount">-<?php echo number_format($_SESSION['applied_voucher']['discount_amount'], 2, ',', '.'); ?> €</span>
                            </div>
                            <?php endif; ?>
                            
                            <!-- Endgesamtsumme -->
                            <div class="total-row final-total">
                                <span class="total-label">Gesamtsumme:</span>
                                <span class="total-amount" id="cart-total">
                                    <?php 
                                    $finalTotal = $totalPrice;
                                    if (isset($_SESSION['applied_voucher'])) {
                                        $finalTotal -= $_SESSION['applied_voucher']['discount_amount'];
                                    }
                                    echo number_format($finalTotal, 2, ',', '.'); 
                                    ?> €
                                </span>
                            </div>
                        </div>
                        <?php endif; ?>
                        
                        <!-- Customer information form -->
                        <div style="margin-top: 40px;">
                            <h2 style="color: var(--primary-color); margin-bottom: 20px;">Ihre Kontaktdaten</h2>
                            
                            <div class="form-group">
                                <label for="customer_name">Name <span class="required-mark">*</span></label>
                                <input type="text" id="customer_name" name="customer_name" class="form-control" required>
                            </div>
                            
                            <div class="form-group">
                                <label for="customer_email">E-Mail <span class="contact-required-mark">*</span></label>
                                <input type="email" id="customer_email" name="customer_email" class="form-control">
                                <small class="form-text text-muted">Entweder E-Mail oder Telefonnummer muss angegeben werden.</small>
                            </div>
                            
                            <div class="form-group">
                                <label for="customer_phone">Telefon <span class="contact-required-mark">*</span></label>
                                <input type="tel" id="customer_phone" name="customer_phone" class="form-control">
                                <small class="form-text text-muted">Entweder E-Mail oder Telefonnummer muss angegeben werden.</small>
                            </div>
                            
                            <!-- Aufgeteilte Adressfelder -->
                            <h3 style="color: var(--primary-color); margin: 25px 0 15px; font-size: 1.2rem;">Adresse</h3>
                            
                            <div class="row">
                                <div class="col-md-8">
                                    <div class="form-group">
                                        <label for="customer_street">Straße <span class="required-mark">*</span></label>
                                        <input type="text" id="customer_street" name="customer_street" class="form-control" required>
                                    </div>
                                </div>
                                <div class="col-md-4">
                                    <div class="form-group">
                                        <label for="customer_house_number">Hausnummer <span class="required-mark">*</span></label>
                                        <input type="text" id="customer_house_number" name="customer_house_number" class="form-control" required>
                                    </div>
                                </div>
                            </div>
                            
                            <div class="row">
                                <div class="col-md-4">
                                    <div class="form-group">
                                        <label for="customer_zip">PLZ <span class="required-mark">*</span></label>
                                        <input type="text" id="customer_zip" name="customer_zip" class="form-control" required>
                                    </div>
                                </div>
                                <div class="col-md-8">
                                    <div class="form-group">
                                        <label for="customer_city">Ort <span class="required-mark">*</span></label>
                                        <input type="text" id="customer_city" name="customer_city" class="form-control" required>
                                    </div>
                                </div>
                            </div>
                            
                            <!-- Verstecktes Feld für die zusammengesetzte Adresse -->
                            <input type="hidden" id="customer_address" name="customer_address" value="">
                            
                            <div class="form-group">
                                <label for="customer_message">Nachricht</label>
                                <textarea id="customer_message" name="customer_message" class="form-control" rows="4"></textarea>
                            </div>
                        </div>
                        
                        <!-- Produktspezifische Formulare -->
                        <?php echo displayProductForms($conn, $products); ?>
                        
                        <div class="form-actions">
                            <a href="order.php" class="btn-link">Zurück zur Produktauswahl</a>
                            
                            <?php if (isset($_GET['error']) && $_GET['error'] == 1): ?>
                            <div style="color: #dc3545; margin: 10px 0; padding: 10px; border: 1px solid #f5c6cb; background: #f8d7da; border-radius: 5px;">
                                <strong>Fehler bei der Bestellung:</strong><br>
                                <?php if (isset($_GET['message'])): ?>
                                    <?php echo htmlspecialchars($_GET['message']); ?>
                                <?php else: ?>
                                    Es ist ein Fehler bei der Bestellverarbeitung aufgetreten. Bitte versuchen Sie es erneut.
                                <?php endif; ?>
                            </div>
                            <?php endif; ?>
                            
                            <button type="submit" id="submit_order_btn" name="submit_order" class="btn" <?php echo $hasError ? 'disabled' : ''; ?>>
                                Bestellung absenden
                            </button>
                        </div>
                        
                        <?php if ($hasError): ?>
                            <div style="color: #dc3545; margin-top: 20px; text-align: center;">
                                <p><i class="fas fa-exclamation-triangle"></i> Es gibt ein Problem mit Ihrer Bestellung. Bitte entfernen Sie Produkte ohne verfügbares Formular.</p>
                            </div>
                        <?php endif; ?>
                    </form>
                </div>
            </div>
        </section>
    </main>
    
    <!-- Footer -->
    <footer class="site-footer">
        <div class="container">
            <div class="footer-content">
                <div class="footer-copyright">
                    <p>&copy; <?php echo date('Y'); ?> <?php echo htmlspecialchars($brand['title'] ?? $site_title); ?>. Alle Rechte vorbehalten.</p>
                </div>
                <div class="footer-links">
                    <a href="impressum.php">Impressum</a>
                    <a href="datenschutz.php">Datenschutz</a>
                </div>
            </div>
        </div>
    </footer>
    
    <script>
        document.addEventListener('DOMContentLoaded', function() {
            // Handle remove item buttons
            const removeButtons = document.querySelectorAll('.remove-btn');
            
            removeButtons.forEach(button => {
                button.addEventListener('click', function() {
                    const productId = this.getAttribute('data-product-id');
                    removeFromCart(productId);
                });
            });
            
            function removeFromCart(productId) {
                // Create a form and submit it to post the removal
                const form = document.createElement('form');
                form.method = 'post';
                form.action = 'order_cart.php';
                
                const inputAction = document.createElement('input');
                inputAction.type = 'hidden';
                inputAction.name = 'action';
                inputAction.value = 'remove';
                
                const inputProductId = document.createElement('input');
                inputProductId.type = 'hidden';
                inputProductId.name = 'product_id';
                inputProductId.value = productId;
                
                form.appendChild(inputAction);
                form.appendChild(inputProductId);
                document.body.appendChild(form);
                form.submit();
            }
            
            // Handle quantity buttons
            const plusButtons = document.querySelectorAll('.quantity-btn.plus');
            const minusButtons = document.querySelectorAll('.quantity-btn.minus');
            const quantityInputs = document.querySelectorAll('.quantity-input');
            
            plusButtons.forEach(button => {
                button.addEventListener('click', function() {
                    const productId = this.getAttribute('data-product-id');
                    const input = document.querySelector(`.quantity-input[data-product-id="${productId}"]`);
                    
                    let value = parseInt(input.value) || 1;
                    value++;
                    input.value = value;
                    updateQuantity(productId, value);
                });
            });
            
            minusButtons.forEach(button => {
                button.addEventListener('click', function() {
                    const productId = this.getAttribute('data-product-id');
                    const input = document.querySelector(`.quantity-input[data-product-id="${productId}"]`);
                    
                    let value = parseInt(input.value) || 2;
                    if (value > 1) {
                        value--;
                        input.value = value;
                        updateQuantity(productId, value);
                    }
                });
            });
            
            quantityInputs.forEach(input => {
                input.addEventListener('change', function() {
                    const productId = this.getAttribute('data-product-id');
                    let value = parseInt(this.value) || 1;
                    
                    // Ensure minimum value is 1
                    if (value < 1) {
                        value = 1;
                        this.value = value;
                    }
                    
                    updateQuantity(productId, value);
                });
            });
            
            // Function to update quantity and prices
            function updateQuantity(productId, quantity) {
                const input = document.querySelector(`.quantity-input[data-product-id="${productId}"]`);
                const itemTotalElement = document.querySelector(`.item-total[data-product-id="${productId}"]`);
                
                if (input) {
                    input.value = quantity;
                    
                    // Update item total only if price is visible
                    const price = parseFloat(input.getAttribute('data-price')) || 0;
                    const showPrice = input.getAttribute('data-show-price') === '1';
                    const itemTotal = price * quantity;
                    
                    if (itemTotalElement && showPrice) {
                        itemTotalElement.textContent = formatPrice(itemTotal) + ' €';
                    }
                    
                    // Update cart total
                    updateCartTotal();
                }
            }
            
            // Function to format price
            function formatPrice(price) {
                // Ensure price is a number
                const numPrice = parseFloat(price) || 0;
                return numPrice.toFixed(2).replace('.', ',').replace(/\B(?=(\d{3})+(?!\d))/g, '.');
            }
            
            // Function to update cart total
            function updateCartTotal() {
                let total = 0;
                let hasVisiblePrices = false;
                
                document.querySelectorAll('.quantity-input').forEach(input => {
                    const quantity = parseInt(input.value) || 0;
                    const price = parseFloat(input.getAttribute('data-price')) || 0;
                    const showPrice = input.getAttribute('data-show-price') === '1';
                    
                    if (showPrice) {
                        total += price * quantity;
                        hasVisiblePrices = true;
                    }
                });
                
                // Zwischensumme aktualisieren
                const subtotalElement = document.getElementById('cart-subtotal');
                if (subtotalElement && hasVisiblePrices) {
                    subtotalElement.textContent = formatPrice(total) + ' €';
                }
                
                // Prüfen, ob ein Gutschein angewendet ist
                const appliedVoucherDiv = document.getElementById('applied-voucher');
                const isVoucherApplied = appliedVoucherDiv && appliedVoucherDiv.style.display !== 'none';
                
                if (isVoucherApplied) {
                    // Gutschein neu validieren mit der neuen Summe
                    const voucherCode = appliedVoucherDiv.querySelector('.voucher-code').textContent;
                    revalidateVoucher(voucherCode, total);
                } else {
                    // Gesamtsumme ohne Gutschein aktualisieren
                    const cartTotalElement = document.getElementById('cart-total');
                    if (cartTotalElement && hasVisiblePrices) {
                        cartTotalElement.textContent = formatPrice(total) + ' €';
                    }
                }
            }
            
            // Funktion zur Neuvalidierung des Gutscheins bei Mengenänderungen
            function revalidateVoucher(voucherCode, newTotal) {
                fetch('ajax_voucher.php', {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/x-www-form-urlencoded',
                    },
                    body: `action=validate_voucher&voucher_code=${encodeURIComponent(voucherCode)}&order_total=${newTotal}`
                })
                .then(response => response.json())
                .then(data => {
                    if (data.success) {
                        // Ensure discount_amount is a number
                        const discountAmount = parseFloat(data.discount_amount) || 0;
                        
                        // Gutschein ist noch gültig, Totals aktualisieren
                        updateCartTotalsWithVoucher(newTotal, discountAmount);
                        
                        // Gutschein-Anzeige aktualisieren
                        const discountElement = document.querySelector('.applied-voucher .voucher-discount');
                        if (discountElement) {
                            discountElement.textContent = '-' + formatPrice(discountAmount) + ' €';
                        }
                    } else {
                        // Gutschein ist nicht mehr gültig, entfernen
                        hideAppliedVoucher();
                        updateCartTotalsWithoutVoucher(newTotal);
                        showVoucherMessage('Gutschein wurde automatisch entfernt: ' + data.message, 'error');
                        
                        // Gutschein aus Session entfernen
                        fetch('ajax_voucher.php', {
                            method: 'POST',
                            headers: {
                                'Content-Type': 'application/x-www-form-urlencoded',
                            },
                            body: 'action=remove_voucher'
                        });
                    }
                })
                .catch(error => {
                    console.error('Error revalidating voucher:', error);
                });
            }
            
            // Sicherstellen, dass das Formular korrekt abgesendet wird
            const submitBtn = document.getElementById('submit_order_btn');
            const orderForm = document.getElementById('orderForm');
            
            if (submitBtn && orderForm) {
                submitBtn.addEventListener('click', function(e) {
                    e.preventDefault();
                    
                    // Formularvalidierung
                    const name = document.getElementById('customer_name').value.trim();
                    const email = document.getElementById('customer_email').value.trim();
                    const phone = document.getElementById('customer_phone').value.trim();
                    
                    // Adressfelder prüfen
                    const street = document.getElementById('customer_street').value.trim();
                    const houseNumber = document.getElementById('customer_house_number').value.trim();
                    const zip = document.getElementById('customer_zip').value.trim();
                    const city = document.getElementById('customer_city').value.trim();
                    
                    // Prüfen der normalen Pflichtfelder
                    if (!name || !street || !houseNumber || !zip || !city) {
                        alert('Bitte füllen Sie alle Pflichtfelder aus.');
                        return;
                    }
                    
                    // Prüfen dass mindestens ein Kontaktfeld (E-Mail oder Telefon) ausgefüllt ist
                    if (!email && !phone) {
                        alert('Bitte geben Sie entweder eine E-Mail-Adresse oder eine Telefonnummer an.');
                        return;
                    }
                    
                    // E-Mail-Validierung (nur wenn ausgefüllt)
                    if (email) {
                        const emailRegex = /^[^\s@]+@[^\s@]+\.[^\s@]+$/;
                        if (!emailRegex.test(email)) {
                            alert('Bitte geben Sie eine gültige E-Mail-Adresse ein.');
                            return;
                        }
                    }
                    
                    // Telefonnummer-Validierung (optional, wenn nötig)
                    
                    // Adresse zusammensetzen
                    const fullAddress = street + ' ' + houseNumber + ', ' + zip + ' ' + city;
                    document.getElementById('customer_address').value = fullAddress;
                    
                    // Formular absenden
                    orderForm.submit();
                });
                
                // Visuelle Rückmeldung zu Kontaktfeldern
                const emailInput = document.getElementById('customer_email');
                const phoneInput = document.getElementById('customer_phone');
                
                function updateContactFieldStatus() {
                    const hasEmail = emailInput.value.trim() !== '';
                    const hasPhone = phoneInput.value.trim() !== '';
                    
                    if (hasEmail) {
                        emailInput.classList.add('contact-field-active');
                        phoneInput.required = false;
                    } else {
                        emailInput.classList.remove('contact-field-active');
                        phoneInput.required = true;
                    }
                    
                    if (hasPhone) {
                        phoneInput.classList.add('contact-field-active');
                        emailInput.required = false;
                    } else {
                        phoneInput.classList.remove('contact-field-active');
                        emailInput.required = true;
                    }
                }
                
                emailInput.addEventListener('input', updateContactFieldStatus);
                phoneInput.addEventListener('input', updateContactFieldStatus);
                
                // Initial setzen
                updateContactFieldStatus();
            }
            
            // Formularhandling für Adressfelder
            const addressForm = document.getElementById('orderForm');
            if (addressForm) {
                addressForm.addEventListener('submit', function(e) {
                    // Adressfelder zusammensetzen
                    const street = document.getElementById('customer_street').value.trim();
                    const houseNumber = document.getElementById('customer_house_number').value.trim();
                    const zip = document.getElementById('customer_zip').value.trim();
                    const city = document.getElementById('customer_city').value.trim();
                    
                    // Komplette Adresse im versteckten Feld speichern
                    const fullAddress = street + ' ' + houseNumber + ', ' + zip + ' ' + city;
                    document.getElementById('customer_address').value = fullAddress;
                });
            }
            
            // Gutschein-Funktionalität
            const voucherCodeInput = document.getElementById('voucher-code');
            const applyVoucherBtn = document.getElementById('apply-voucher-btn');
            const removeVoucherBtn = document.getElementById('remove-voucher-btn');
            const voucherMessage = document.getElementById('voucher-message');
            
            // Automatische Großschreibung für Gutscheincode
            if (voucherCodeInput) {
                voucherCodeInput.addEventListener('input', function() {
                    this.value = this.value.toUpperCase().replace(/[^A-Z0-9]/g, '');
                });
                
                // Enter-Taste zum Einlösen
                voucherCodeInput.addEventListener('keypress', function(e) {
                    if (e.key === 'Enter') {
                        e.preventDefault();
                        applyVoucher();
                    }
                });
            }
            
            // Gutschein einlösen
            if (applyVoucherBtn) {
                applyVoucherBtn.addEventListener('click', applyVoucher);
            }
            
            // Gutschein entfernen
            if (removeVoucherBtn) {
                removeVoucherBtn.addEventListener('click', removeVoucher);
            }
            
            function applyVoucher() {
                const code = voucherCodeInput.value.trim();
                
                if (!code) {
                    showVoucherMessage('Bitte geben Sie einen Gutscheincode ein.', 'error');
                    return;
                }
                
                // Aktuelle Gesamtsumme berechnen
                const orderTotal = calculateCurrentTotal();
                
                console.log('Applying voucher:', code, 'Order total:', orderTotal);
                
                // Button deaktivieren während der Anfrage
                applyVoucherBtn.disabled = true;
                applyVoucherBtn.textContent = 'Prüfe...';
                
                // AJAX-Anfrage
                fetch('ajax_voucher.php', {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/x-www-form-urlencoded',
                    },
                    body: `action=validate_voucher&voucher_code=${encodeURIComponent(code)}&order_total=${orderTotal}`
                })
                .then(response => {
                    console.log('Response status:', response.status);
                    console.log('Response headers:', response.headers);
                    
                    if (!response.ok) {
                        throw new Error(`HTTP error! status: ${response.status}`);
                    }
                    
                    return response.text(); // Erst als Text lesen für Debugging
                })
                .then(text => {
                    console.log('Raw response:', text);
                    
                    try {
                        const data = JSON.parse(text);
                        console.log('Parsed response:', data);
                        
                        if (data.success) {
                            showVoucherMessage(data.message, 'success');
                            
                            // Gutschein-Eingabefeld leeren
                            voucherCodeInput.value = '';
                            
                            // Ensure discount_amount is a number
                            const discountAmount = parseFloat(data.discount_amount) || 0;
                            
                            // Angewendeten Gutschein anzeigen
                            showAppliedVoucher(data.voucher_data, discountAmount);
                            
                            // Cart-Totals aktualisieren
                            updateCartTotalsWithVoucher(orderTotal, discountAmount);
                            
                        } else {
                            showVoucherMessage(data.message, 'error');
                        }
                    } catch (parseError) {
                        console.error('JSON parse error:', parseError);
                        console.error('Response text:', text);
                        showVoucherMessage('Fehler beim Verarbeiten der Server-Antwort.', 'error');
                    }
                })
                .catch(error => {
                    console.error('Fetch error:', error);
                    showVoucherMessage('Netzwerkfehler bei der Gutschein-Validierung: ' + error.message, 'error');
                })
                .finally(() => {
                    // Button wieder aktivieren
                    applyVoucherBtn.disabled = false;
                    applyVoucherBtn.textContent = 'Einlösen';
                });
            }
            
            function removeVoucher() {
                // AJAX-Anfrage zum Entfernen des Gutscheins
                fetch('ajax_voucher.php', {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/x-www-form-urlencoded',
                    },
                    body: 'action=remove_voucher'
                })
                .then(response => response.json())
                .then(data => {
                    if (data.success) {
                        // Angewendeten Gutschein ausblenden
                        hideAppliedVoucher();
                        
                        // Cart-Totals ohne Gutschein aktualisieren
                        const orderTotal = calculateCurrentTotal();
                        updateCartTotalsWithoutVoucher(orderTotal);
                        
                        showVoucherMessage('Gutschein wurde entfernt.', 'success');
                    }
                })
                .catch(error => {
                    console.error('Error:', error);
                });
            }
            
            function showAppliedVoucher(voucherData, discountAmount) {
                // Prüfen, ob bereits ein angewendeter Gutschein angezeigt wird
                let appliedVoucherDiv = document.getElementById('applied-voucher');
                
                if (!appliedVoucherDiv) {
                    // Neues Element erstellen
                    appliedVoucherDiv = document.createElement('div');
                    appliedVoucherDiv.id = 'applied-voucher';
                    appliedVoucherDiv.className = 'applied-voucher';
                    
                    // Nach der voucher-message einfügen
                    const voucherSection = document.querySelector('.voucher-section');
                    voucherSection.appendChild(appliedVoucherDiv);
                }
                
                appliedVoucherDiv.innerHTML = `
                    <div class="voucher-info">
                        <span class="voucher-code">${voucherData.code}</span>
                        <span class="voucher-description">${voucherData.description}</span>
                    </div>
                    <div class="voucher-discount">
                        -${formatPrice(discountAmount)} €
                    </div>
                    <button type="button" id="remove-voucher-btn" class="remove-voucher-btn">
                        <i class="fas fa-times"></i>
                    </button>
                `;
                
                // Event-Listener für den Remove-Button hinzufügen
                const newRemoveBtn = appliedVoucherDiv.querySelector('#remove-voucher-btn');
                if (newRemoveBtn) {
                    newRemoveBtn.addEventListener('click', removeVoucher);
                }
                
                appliedVoucherDiv.style.display = 'flex';
            }
            
            function hideAppliedVoucher() {
                const appliedVoucherDiv = document.getElementById('applied-voucher');
                if (appliedVoucherDiv) {
                    appliedVoucherDiv.style.display = 'none';
                }
                
                // Rabatt-Zeile ausblenden
                const discountRow = document.querySelector('.discount-row');
                if (discountRow) {
                    discountRow.style.display = 'none';
                }
            }
            
            function updateCartTotalsWithVoucher(subtotal, discountAmount) {
                const finalTotal = subtotal - discountAmount;
                
                // Zwischensumme aktualisieren
                const subtotalElement = document.getElementById('cart-subtotal');
                if (subtotalElement) {
                    subtotalElement.textContent = formatPrice(subtotal) + ' €';
                }
                
                // Rabatt-Zeile anzeigen/aktualisieren
                let discountRow = document.querySelector('.discount-row');
                if (!discountRow) {
                    // Neue Rabatt-Zeile erstellen
                    const cartTotal = document.querySelector('.cart-total');
                    const finalTotalRow = document.querySelector('.final-total');
                    
                    discountRow = document.createElement('div');
                    discountRow.className = 'total-row discount-row';
                    discountRow.innerHTML = `
                        <span class="total-label">Rabatt:</span>
                        <span class="total-amount discount-amount" id="cart-discount">-${formatPrice(discountAmount)} €</span>
                    `;
                    
                    // Vor der finalen Gesamtsumme einfügen
                    cartTotal.insertBefore(discountRow, finalTotalRow);
                } else {
                    // Bestehende Rabatt-Zeile aktualisieren
                    const discountElement = document.getElementById('cart-discount');
                    if (discountElement) {
                        discountElement.textContent = '-' + formatPrice(discountAmount) + ' €';
                    }
                    discountRow.style.display = 'flex';
                }
                
                // Gesamtsumme aktualisieren
                const totalElement = document.getElementById('cart-total');
                if (totalElement) {
                    totalElement.textContent = formatPrice(finalTotal) + ' €';
                }
            }
            
            function updateCartTotalsWithoutVoucher(subtotal) {
                // Zwischensumme aktualisieren
                const subtotalElement = document.getElementById('cart-subtotal');
                if (subtotalElement) {
                    subtotalElement.textContent = formatPrice(subtotal) + ' €';
                }
                
                // Gesamtsumme aktualisieren (ohne Rabatt)
                const totalElement = document.getElementById('cart-total');
                if (totalElement) {
                    totalElement.textContent = formatPrice(subtotal) + ' €';
                }
            }
            
            function showVoucherMessage(message, type) {
                voucherMessage.textContent = message;
                voucherMessage.className = `voucher-message ${type}`;
                
                // Nachricht nach 5 Sekunden ausblenden
                setTimeout(() => {
                    voucherMessage.textContent = '';
                    voucherMessage.className = 'voucher-message';
                }, 5000);
            }
            
            function calculateCurrentTotal() {
                let total = 0;
                
                document.querySelectorAll('.quantity-input').forEach(input => {
                    const quantity = parseInt(input.value) || 0;
                    const price = parseFloat(input.getAttribute('data-price')) || 0;
                    const showPrice = input.getAttribute('data-show-price') === '1';
                    
                    if (showPrice) {
                        total += price * quantity;
                    }
                });
                
                return total;
            }
        });
    </script>
</body>
</html> 