<?php
session_start();

// Include cache utilities to prevent form caching issues
require_once('includes/form_cache_fix.php');
$cacheBuster = invalidateFormCache();

require_once('includes/db_connect.php');

// Get form ID from query string
$form_id = isset($_GET['id']) ? intval($_GET['id']) : 0;
$embedded = isset($_GET['embedded']) && $_GET['embedded'] == 1;

if ($form_id <= 0) {
    header('Location: index.php');
    exit;
}

// Initialize variables
$form = null;
$fields = [];
$errors = [];
$success = false;

// Fetch the form and its fields
try {
    // Get form data
    $stmt = $conn->prepare("
        SELECT f.*, p.name as product_name, p.image_path as product_image
        FROM order_forms f
        LEFT JOIN products p ON f.product_id = p.id
        WHERE f.id = :id AND f.active = 1
    ");
    $stmt->bindParam(':id', $form_id);
    $stmt->execute();
    
    $form = $stmt->fetch(PDO::FETCH_ASSOC);
    
    if (!$form) {
        header('Location: index.php');
        exit;
    }
    
    // Get form fields - Directly ensure address field types in the query
    $conn->exec("UPDATE form_fields SET field_type = 'address' 
                 WHERE form_id = {$form_id} AND 
                 (field_label LIKE '%dresse%' OR field_label LIKE '%Adresse%')");
                 
    $stmt = $conn->prepare("SELECT * FROM form_fields WHERE form_id = :form_id ORDER BY sort_order");
    $stmt->bindParam(':form_id', $form_id);
    $stmt->execute();
    $fields = $stmt->fetchAll(PDO::FETCH_ASSOC);
    
} catch (PDOException $e) {
    die("Fehler beim Laden des Formulars: " . $e->getMessage());
}

// Process form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['submit_order'])) {
    // Process address field parts
    foreach ($fields as $field) {
        if ($field['field_type'] === 'address') {
            $field_id = $field['id'];
            $field_name = 'field_' . $field_id;
            
            // Get address components
            $street = isset($_POST[$field_name . '_street']) ? trim($_POST[$field_name . '_street']) : '';
            $number = isset($_POST[$field_name . '_number']) ? trim($_POST[$field_name . '_number']) : '';
            $zip = isset($_POST[$field_name . '_zip']) ? trim($_POST[$field_name . '_zip']) : '';
            $city = isset($_POST[$field_name . '_city']) ? trim($_POST[$field_name . '_city']) : '';
            
            // Combine into a full address
            $address = $street . ' ' . $number . ', ' . $zip . ' ' . $city;
            $_POST[$field_name] = trim($address);
            
            // Validate required address fields
            if ($field['required'] == 1) {
                if (empty($street) || empty($number) || empty($zip) || empty($city)) {
                    $errors[$field_name] = 'Alle Felder der Adresse sind erforderlich';
                }
            }
        }
    }
    
    // Validate all other fields
    foreach ($fields as $field) {
        $field_name = 'field_' . $field['id'];
        
        // Skip address fields as they were handled above
        if ($field['field_type'] === 'address') continue;
        
        // Check required fields
        if ($field['required'] == 1 && empty($_POST[$field_name])) {
            $errors[$field_name] = 'Dieses Feld ist erforderlich';
        }
        
        // Email validation
        if ($field['field_type'] == 'email' && !empty($_POST[$field_name])) {
            if (!filter_var($_POST[$field_name], FILTER_VALIDATE_EMAIL)) {
                $errors[$field_name] = 'Bitte geben Sie eine gültige E-Mail-Adresse ein';
            }
        }
    }
    
    // If no errors, save the submission
    if (empty($errors)) {
        try {
            $conn->beginTransaction();
            
            // Create submission record
            $stmt = $conn->prepare("
                INSERT INTO order_submissions (form_id, submission_date) 
                VALUES (:form_id, NOW())
            ");
            $stmt->bindParam(':form_id', $form_id);
            $stmt->execute();
            
            $submission_id = $conn->lastInsertId();
            
            // Save field values
            $stmt = $conn->prepare("
                INSERT INTO submission_values (submission_id, field_id, field_value) 
                VALUES (:submission_id, :field_id, :field_value)
            ");
            
            // Prepare email content
            $emailSubject = "Neue Bestellung: " . $form['title'];
            $emailBody = "Eine neue Bestellung wurde eingereicht:\n\n";
            $emailBody .= "Formular: " . $form['title'] . "\n";
            if ($form['product_name']) {
                $emailBody .= "Produkt: " . $form['product_name'] . "\n";
            }
            $emailBody .= "Datum: " . date('d.m.Y H:i:s') . "\n\n";
            $emailBody .= "Bestelldaten:\n";
            
            // Process all fields
            foreach ($fields as $field) {
                $field_id = $field['id'];
                $field_name = 'field_' . $field_id;
                $field_value = isset($_POST[$field_name]) ? $_POST[$field_name] : '';
                
                // Handle arrays (checkboxes)
                if (is_array($field_value)) {
                    $field_value = implode(', ', $field_value);
                }
                
                // Save to database
                $stmt->bindParam(':submission_id', $submission_id);
                $stmt->bindParam(':field_id', $field_id);
                $stmt->bindParam(':field_value', $field_value);
                $stmt->execute();
                
                // Add to email
                $emailBody .= $field['field_label'] . ": " . $field_value . "\n";
            }
            
            $conn->commit();
            
            // Send notification email
            $to = "info@ke-lo.xyz"; // Change to site admin email
            $headers = "From: noreply@" . $_SERVER['HTTP_HOST'] . "\r\n";
            
            mail($to, $emailSubject, $emailBody, $headers);
            
            $success = true;
            
        } catch (PDOException $e) {
            $conn->rollBack();
            $errors['general'] = 'Fehler beim Speichern der Bestellung: ' . $e->getMessage();
        }
    }
}

// Get site colors for styling
try {
    $stmt = $conn->query("SELECT setting_name, setting_value FROM site_settings WHERE setting_name IN ('primary_color', 'secondary_color', 'accent_color')");
    $colors = $stmt->fetchAll(PDO::FETCH_KEY_PAIR);
} catch (PDOException $e) {
    // Use default colors if query fails
    $colors = [
        'primary_color' => '#8b6b4f',
        'secondary_color' => '#333333',
        'accent_color' => '#d4af37'
    ];
}

// If colors not found, use defaults
if (!isset($colors['primary_color'])) $colors['primary_color'] = '#8b6b4f';
if (!isset($colors['secondary_color'])) $colors['secondary_color'] = '#333333';
if (!isset($colors['accent_color'])) $colors['accent_color'] = '#d4af37';

// Get site title
$stmt = $conn->prepare("SELECT setting_value FROM site_settings WHERE setting_name = 'site_title'");
$stmt->execute();
$site_title = $stmt->fetchColumn() ?: 'JB Kerzen';

// Get brand info for header
$stmt = $conn->prepare("SELECT * FROM brand_info WHERE id = 1");
$stmt->execute();
$brand = $stmt->fetch();

// Get order logo
$stmt = $conn->prepare("SELECT setting_value FROM site_settings WHERE setting_name = 'order_logo'");
$stmt->execute();
$order_logo = $stmt->fetchColumn() ?: '';
?>

<!DOCTYPE html>
<html lang="de">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo htmlspecialchars($form['title']); ?> | <?php echo htmlspecialchars($site_title); ?></title>
    <?php if (!$embedded): ?>
    <link rel="stylesheet" href="assets/css/style.css">
    <link rel="stylesheet" href="assets/css/center-fix.css">
    <link rel="stylesheet" href="assets/css/order-forms.css">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css">
    <?php endif; ?>
    <style>
        :root {
            --primary-color: <?php echo $colors['primary_color']; ?>;
            --secondary-color: <?php echo $colors['secondary_color']; ?>;
            --accent-color: <?php echo $colors['accent_color']; ?>;
        }
        
        body {
            font-family: 'Helvetica Neue', Arial, sans-serif;
            line-height: 1.6;
            color: #333;
            margin: 0;
            padding: 0;
            background-color: #f8f8f8;
        }
        
        .container {
            max-width: 800px;
            margin: 0 auto;
            padding: 0 20px;
        }
        
        .form-container {
            background: white;
            border-radius: 10px;
            box-shadow: 0 3px 15px rgba(0,0,0,0.1);
            padding: 30px;
            margin: 20px 0;
        }
        
        .form-header {
            margin-bottom: 30px;
            text-align: center;
        }
        
        .form-header h1 {
            color: var(--primary-color);
            font-size: 28px;
            margin-bottom: 10px;
        }
        
        .form-header p {
            color: #666;
            font-size: 16px;
        }
        
        .product-info {
            display: flex;
            align-items: center;
            margin-bottom: 25px;
            padding: 15px;
            background-color: #f9f9f9;
            border-radius: 8px;
        }
        
        .product-image {
            width: 80px;
            height: 80px;
            object-fit: contain;
            margin-right: 15px;
        }
        
        .product-details h3 {
            color: var(--primary-color);
            margin: 0 0 5px 0;
        }
        
        .form-group {
            margin-bottom: 25px;
        }
        
        .form-group label {
            display: block;
            font-weight: 500;
            margin-bottom: 8px;
            color: var(--secondary-color);
        }
        
        .form-control {
            width: 100%;
            padding: 12px 15px;
            font-size: 16px;
            border: 1px solid #ddd;
            border-radius: 5px;
            transition: border-color 0.3s;
        }
        
        .form-control:focus {
            border-color: var(--primary-color);
            outline: none;
        }
        
        .text-danger {
            color: #dc3545;
            font-size: 14px;
            margin-top: 5px;
        }
        
        .required-mark {
            color: #dc3545;
            margin-left: 3px;
        }
        
        .checkbox-group,
        .radio-group {
            display: flex;
            flex-direction: column;
            gap: 10px;
            margin-top: 8px;
        }
        
        .checkbox-option,
        .radio-option {
            display: flex;
            align-items: center;
        }
        
        .checkbox-option input,
        .radio-option input {
            margin-right: 10px;
        }
        
        /* New cleaner address field styles */
        .address-container {
            border: 1px solid #ddd;
            border-radius: 5px;
            padding: 15px;
            background: #f9f9f9;
        }
        
        .address-row {
            display: flex;
            gap: 15px;
            margin-bottom: 15px;
        }
        
        .address-col {
            flex: 1;
        }
        
        .address-col.street {
            flex: 2;
        }
        
        .address-label {
            display: block;
            font-weight: 500;
            margin-bottom: 5px;
            font-size: 14px;
        }
        
        @media (max-width: 768px) {
            .address-row {
                flex-direction: column;
                gap: 10px;
            }
        }
        
        .btn {
            display: inline-block;
            background-color: var(--primary-color);
            color: white;
            font-size: 16px;
            font-weight: 500;
            padding: 12px 25px;
            border: none;
            border-radius: 5px;
            cursor: pointer;
            transition: background-color 0.3s;
        }
        
        .btn:hover {
            background-color: var(--accent-color);
        }
        
        .btn-link {
            background: none;
            color: var(--primary-color);
            text-decoration: underline;
            border: none;
            padding: 0;
            font-size: 16px;
            cursor: pointer;
        }
        
        .btn-link:hover {
            color: var(--accent-color);
            background: none;
        }
        
        .form-actions {
            margin-top: 30px;
            display: flex;
            justify-content: space-between;
            align-items: center;
        }
        
        .success-message {
            text-align: center;
            padding: 40px 20px;
        }
        
        .success-message .icon {
            color: #28a745;
            font-size: 60px;
            margin-bottom: 20px;
        }
        
        .success-message h2 {
            color: var(--primary-color);
            margin-bottom: 15px;
        }
        
        .success-message p {
            color: #666;
            margin-bottom: 25px;
            font-size: 18px;
        }
        
        .alert {
            padding: 15px;
            margin-bottom: 20px;
            border-radius: 5px;
        }
        
        .alert-danger {
            background-color: #f8d7da;
            border: 1px solid #f5c6cb;
            color: #721c24;
        }
        
        /* Styles for embedded mode */
        .embedded-form {
            margin: 0;
            padding: 0;
            background: transparent;
        }
        
        .embedded-form .form-container {
            box-shadow: none;
            padding: 0;
            margin: 0;
        }
        
        /* Header and footer (only for non-embedded view) */
        .site-header {
            background-color: white;
            box-shadow: 0 2px 10px rgba(0,0,0,0.1);
            padding: 15px 0;
        }
        
        .header-content {
            display: flex;
            justify-content: space-between;
            align-items: center;
        }
        
        .brand-text {
            font-size: 24px;
            color: var(--primary-color);
            text-decoration: none;
            font-weight: bold;
        }
        
        .brand-logo {
            height: 60px;
            width: auto;
        }
        
        .back-link {
            color: var(--primary-color);
            text-decoration: none;
            display: flex;
            align-items: center;
            gap: 5px;
        }
        
        .back-link:hover {
            color: var(--accent-color);
        }
        
        .site-footer {
            background-color: var(--secondary-color);
            color: white;
            padding: 30px 0;
            margin-top: 50px;
        }
        
        .footer-content {
            display: flex;
            flex-direction: column;
            align-items: center;
            text-align: center;
        }
        
        .footer-copyright {
            margin-bottom: 15px;
        }
        
        .footer-links {
            display: flex;
            gap: 20px;
        }
        
        .footer-links a {
            color: white;
            text-decoration: none;
        }
        
        .footer-links a:hover {
            text-decoration: underline;
        }
        
        /* Responsive styles */
        @media (max-width: 768px) {
            .form-container {
                padding: 20px;
            }
            
            .product-info {
                flex-direction: column;
                text-align: center;
            }
            
            .product-image {
                margin-right: 0;
                margin-bottom: 10px;
            }
            
            .form-actions {
                flex-direction: column;
                gap: 15px;
            }
            
            .btn {
                width: 100%;
            }
        }
    </style>
</head>
<body class="<?php echo $embedded ? 'embedded-form' : ''; ?>">
    <?php if (!$embedded): ?>
    <!-- Header -->
    <header class="site-header">
        <div class="container">
            <div class="header-content">
                <div class="brand">
                    <?php if (!empty($order_logo) && file_exists($order_logo)): ?>
                        <a href="index.php">
                            <img src="<?php echo htmlspecialchars($order_logo); ?>" alt="<?php echo htmlspecialchars($site_title); ?>" class="brand-logo">
                        </a>
                    <?php elseif (isset($brand['image_path']) && !empty($brand['image_path'])): ?>
                        <a href="index.php">
                            <img src="<?php echo htmlspecialchars($brand['image_path']); ?>" alt="<?php echo htmlspecialchars($brand['title'] ?? $site_title); ?>" class="brand-logo">
                        </a>
                    <?php else: ?>
                        <a href="index.php" class="brand-text">
                            <?php echo htmlspecialchars($brand['title'] ?? $site_title); ?>
                        </a>
                    <?php endif; ?>
                </div>
                
                <a href="order.php" class="back-link">
                    <i class="fas fa-arrow-left"></i> Zurück zur Produktauswahl
                </a>
            </div>
        </div>
    </header>
    <?php endif; ?>
    
    <div class="container">
        <div class="form-container">
            <?php if ($success): ?>
                <!-- Success Message -->
                <div class="success-message">
                    <div class="icon"><i class="fas fa-check-circle"></i></div>
                    <h2>Vielen Dank für Ihre Bestellung!</h2>
                    <p>Wir haben Ihre Anfrage erhalten und werden uns schnellstmöglich mit Ihnen in Verbindung setzen.</p>
                    
                    <?php if (!$embedded): ?>
                        <a href="index.php" class="btn">Zurück zur Startseite</a>
                    <?php else: ?>
                        <button type="button" class="btn-link" onclick="window.parent.location.href='index.php'">Zurück zur Startseite</button>
                    <?php endif; ?>
                </div>
            <?php else: ?>
                <!-- Order Form -->
                <div class="form-header">
                    <h1><?php echo htmlspecialchars($form['title']); ?></h1>
                    <?php if (!empty($form['description'])): ?>
                        <p><?php echo nl2br(htmlspecialchars($form['description'])); ?></p>
                    <?php endif; ?>
                </div>
                
                <?php if ($form['product_name']): ?>
                    <div class="product-info">
                        <?php if (!empty($form['product_image'])): ?>
                            <img src="<?php echo htmlspecialchars($form['product_image']); ?>" alt="<?php echo htmlspecialchars($form['product_name']); ?>" class="product-image">
                        <?php endif; ?>
                        <div class="product-details">
                            <h3><?php echo htmlspecialchars($form['product_name']); ?></h3>
                        </div>
                    </div>
                <?php endif; ?>
                
                <?php if (isset($errors['general'])): ?>
                    <div class="alert alert-danger"><?php echo $errors['general']; ?></div>
                <?php endif; ?>
                
                <form method="post" action="">
                    <?php 
                    // Group fields by type
                    $emailField = null;
                    $addressField = null;
                    $phoneField = null;
                    $commentField = null;
                    $otherFields = [];
                    
                    foreach ($fields as $field) {
                        $field_id = $field['id'];
                        $field_name = 'field_' . $field_id;
                        $field_label = $field['field_label'];
                        $field_type = $field['field_type'];
                        $field_options = $field['field_options'];
                        $is_required = $field['required'] == 1;
                        $error = isset($errors[$field_name]) ? $errors[$field_name] : '';
                        $value = isset($_POST[$field_name]) ? $_POST[$field_name] : '';
                        
                        $fieldData = [
                            'id' => $field_id,
                            'name' => $field_name,
                            'label' => $field_label,
                            'type' => $field_type,
                            'options' => $field_options,
                            'required' => $is_required,
                            'error' => $error,
                            'value' => $value
                        ];
                        
                        // Group by type
                        if ($field_type === 'email') {
                            $emailField = $fieldData;
                        } 
                        elseif ($field_type === 'tel') {
                            $phoneField = $fieldData;
                        }
                        elseif ($field_type === 'address') {
                            $addressField = $fieldData;
                        }
                        elseif ($field_type === 'textarea' && (
                            stripos($field_label, 'bemerkung') !== false || 
                            stripos($field_label, 'kommentar') !== false ||
                            stripos($field_label, 'nachricht') !== false
                        )) {
                            $commentField = $fieldData;
                        }
                        else {
                            $otherFields[] = $fieldData;
                        }
                    }
                    
                    // Render fields in specific order
                    if ($emailField) renderField($emailField);
                    if ($phoneField) renderField($phoneField);
                    if ($addressField) renderAddressField($addressField);
                    
                    // Render other fields
                    foreach ($otherFields as $field) {
                        renderField($field);
                    }
                    
                    // Always render comment field last
                    if ($commentField) {
                        renderField($commentField);
                    }
                    
                    /**
                     * Render a standard form field
                     */
                    function renderField($field) {
                        extract($field);
                        ?>
                        <div class="form-group">
                            <label for="<?php echo $name; ?>">
                                <?php echo htmlspecialchars($label); ?>
                                <?php if ($required): ?><span class="required-mark">*</span><?php endif; ?>
                            </label>
                            
                            <?php if ($type === 'text' || $type === 'email' || $type === 'tel'): ?>
                                <input type="<?php echo $type; ?>" 
                                       id="<?php echo $name; ?>" 
                                       name="<?php echo $name; ?>" 
                                       class="form-control <?php echo !empty($error) ? 'is-invalid' : ''; ?>" 
                                       value="<?php echo htmlspecialchars($value); ?>"
                                       <?php echo $required ? 'required' : ''; ?>>
                                       
                            <?php elseif ($type === 'textarea'): ?>
                                <textarea id="<?php echo $name; ?>" 
                                          name="<?php echo $name; ?>" 
                                          class="form-control <?php echo !empty($error) ? 'is-invalid' : ''; ?>" 
                                          rows="4"
                                          <?php echo $required ? 'required' : ''; ?>><?php echo htmlspecialchars($value); ?></textarea>
                                          
                            <?php elseif ($type === 'select'): ?>
                                <select id="<?php echo $name; ?>" 
                                        name="<?php echo $name; ?>" 
                                        class="form-control <?php echo !empty($error) ? 'is-invalid' : ''; ?>"
                                        <?php echo $required ? 'required' : ''; ?>>
                                    <option value="">-- Bitte wählen --</option>
                                    <?php 
                                    $options_list = explode("\n", $options);
                                    foreach ($options_list as $option): 
                                        $option = trim($option);
                                        if (empty($option)) continue;
                                    ?>
                                        <option value="<?php echo htmlspecialchars($option); ?>" <?php echo $value === $option ? 'selected' : ''; ?>>
                                            <?php echo htmlspecialchars($option); ?>
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                                
                            <?php elseif ($type === 'checkbox'): ?>
                                <div class="checkbox-group">
                                    <?php 
                                    $options_list = explode("\n", $options);
                                    $selected = is_array($value) ? $value : [];
                                    
                                    foreach ($options_list as $index => $option): 
                                        $option = trim($option);
                                        if (empty($option)) continue;
                                        $option_id = $name . '_' . $index;
                                        $is_checked = in_array($option, $selected);
                                    ?>
                                        <div class="checkbox-option">
                                            <input type="checkbox" 
                                                   id="<?php echo $option_id; ?>" 
                                                   name="<?php echo $name; ?>[]" 
                                                   value="<?php echo htmlspecialchars($option); ?>"
                                                   <?php echo $is_checked ? 'checked' : ''; ?>>
                                            <label for="<?php echo $option_id; ?>"><?php echo htmlspecialchars($option); ?></label>
                                        </div>
                                    <?php endforeach; ?>
                                </div>
                                
                            <?php elseif ($type === 'radio'): ?>
                                <div class="radio-group">
                                    <?php 
                                    $options_list = explode("\n", $options);
                                    foreach ($options_list as $index => $option): 
                                        $option = trim($option);
                                        if (empty($option)) continue;
                                        $option_id = $name . '_' . $index;
                                        $is_checked = $value === $option;
                                    ?>
                                        <div class="radio-option">
                                            <input type="radio" 
                                                   id="<?php echo $option_id; ?>" 
                                                   name="<?php echo $name; ?>" 
                                                   value="<?php echo htmlspecialchars($option); ?>"
                                                   <?php echo $is_checked ? 'checked' : ''; ?>
                                                   <?php echo $required ? 'required' : ''; ?>>
                                            <label for="<?php echo $option_id; ?>"><?php echo htmlspecialchars($option); ?></label>
                                        </div>
                                    <?php endforeach; ?>
                                </div>
                            <?php endif; ?>
                            
                            <?php if (!empty($error)): ?>
                                <div class="text-danger"><?php echo $error; ?></div>
                            <?php endif; ?>
                        </div>
                        <?php
                    }
                    
                    /**
                     * Render an address field with its subfields
                     */
                    function renderAddressField($field) {
                        extract($field);
                        
                        // Get saved parts if they exist, otherwise set defaults
                        $street_value = isset($_POST[$name . '_street']) ? $_POST[$name . '_street'] : '';
                        $number_value = isset($_POST[$name . '_number']) ? $_POST[$name . '_number'] : '';
                        $zip_value = isset($_POST[$name . '_zip']) ? $_POST[$name . '_zip'] : '';
                        $city_value = isset($_POST[$name . '_city']) ? $_POST[$name . '_city'] : '';
                        ?>
                        <div class="form-group">
                            <label>
                                <?php echo htmlspecialchars($label); ?>
                                <?php if ($required): ?><span class="required-mark">*</span><?php endif; ?>
                            </label>
                            
                            <div class="address-container">
                                <div class="address-row">
                                    <div class="address-col street">
                                        <label class="address-label" for="<?php echo $name; ?>_street">Straße</label>
                                        <input type="text" 
                                               id="<?php echo $name; ?>_street" 
                                               name="<?php echo $name; ?>_street" 
                                               class="form-control"
                                               value="<?php echo htmlspecialchars($street_value); ?>"
                                               <?php echo $required ? 'required' : ''; ?>>
                                    </div>
                                    <div class="address-col">
                                        <label class="address-label" for="<?php echo $name; ?>_number">Hausnummer</label>
                                        <input type="text" 
                                               id="<?php echo $name; ?>_number" 
                                               name="<?php echo $name; ?>_number" 
                                               class="form-control"
                                               value="<?php echo htmlspecialchars($number_value); ?>"
                                               <?php echo $required ? 'required' : ''; ?>>
                                    </div>
                                </div>
                                <div class="address-row">
                                    <div class="address-col">
                                        <label class="address-label" for="<?php echo $name; ?>_zip">PLZ</label>
                                        <input type="text" 
                                               id="<?php echo $name; ?>_zip" 
                                               name="<?php echo $name; ?>_zip" 
                                               class="form-control"
                                               value="<?php echo htmlspecialchars($zip_value); ?>"
                                               <?php echo $required ? 'required' : ''; ?>>
                                    </div>
                                    <div class="address-col street">
                                        <label class="address-label" for="<?php echo $name; ?>_city">Stadt</label>
                                        <input type="text" 
                                               id="<?php echo $name; ?>_city" 
                                               name="<?php echo $name; ?>_city" 
                                               class="form-control"
                                               value="<?php echo htmlspecialchars($city_value); ?>"
                                               <?php echo $required ? 'required' : ''; ?>>
                                    </div>
                                </div>
                            </div>
                            
                            <!-- Hidden field for combined address -->
                            <input type="hidden" name="<?php echo $name; ?>" id="<?php echo $name; ?>" value="">
                            
                            <script>
                                // Combine address values on form submit
                                document.addEventListener('DOMContentLoaded', function() {
                                    const form = document.querySelector('form');
                                    const hiddenField = document.getElementById('<?php echo $name; ?>');
                                    
                                    form.addEventListener('submit', function() {
                                        const street = document.getElementById('<?php echo $name; ?>_street').value;
                                        const number = document.getElementById('<?php echo $name; ?>_number').value;
                                        const zip = document.getElementById('<?php echo $name; ?>_zip').value;
                                        const city = document.getElementById('<?php echo $name; ?>_city').value;
                                        
                                        hiddenField.value = street + ' ' + number + ', ' + zip + ' ' + city;
                                    });
                                });
                            </script>
                            
                            <?php if (!empty($error)): ?>
                                <div class="text-danger"><?php echo $error; ?></div>
                            <?php endif; ?>
                        </div>
                        <?php
                    }
                    ?>
                    
                    <div class="form-actions">
                        <?php if (!$embedded): ?>
                            <a href="order.php" class="btn-link">Zurück zur Produktauswahl</a>
                        <?php else: ?>
                            <button type="button" class="btn-link" onclick="window.parent.location.href='order.php'">Zurück zur Produktauswahl</button>
                        <?php endif; ?>
                        
                        <button type="submit" name="submit_order" class="btn">Bestellung absenden</button>
                    </div>
                </form>
            <?php endif; ?>
        </div>
    </div>
    
    <?php if (!$embedded): ?>
    <!-- Footer -->
    <footer class="site-footer">
        <div class="container">
            <div class="footer-content">
                <div class="footer-copyright">
                    <p>&copy; <?php echo date('Y'); ?> <?php echo htmlspecialchars($brand['title'] ?? $site_title); ?>. Alle Rechte vorbehalten.</p>
                </div>
                <div class="footer-links">
                    <a href="impressum.php">Impressum</a>
                    <a href="datenschutz.php">Datenschutz</a>
                </div>
            </div>
        </div>
    </footer>
    <?php endif; ?>
    
    <?php if ($embedded): ?>
    <script>
        // Send form height to parent window
        window.addEventListener('load', function() {
            const formHeight = document.body.scrollHeight;
            window.parent.postMessage({
                type: 'formHeight',
                height: formHeight
            }, '*');
        });
    </script>
    <?php endif; ?>
</body>
</html> 