<?php
/**
 * Formular-Manager für den Bestellprozess
 * 
 * Ermöglicht die Verwaltung und Anzeige produktspezifischer Formulare
 */

/**
 * Lädt die Formularfelder für ein bestimmtes Formular
 *
 * @param PDO $conn Die Datenbankverbindung
 * @param int $formId Die ID des Formulars
 * @return array Die Felder des Formulars oder leeres Array bei Fehler
 */
function loadFormFields($conn, $formId) {
    if (empty($formId)) {
        return [];
    }
    
    try {
        $stmt = $conn->prepare("
            SELECT * FROM form_fields 
            WHERE form_id = :form_id
            ORDER BY sort_order
        ");
        $stmt->bindParam(':form_id', $formId);
        $stmt->execute();
        
        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    } catch (PDOException $e) {
        error_log("Fehler beim Laden der Formularfelder: " . $e->getMessage());
        return [];
    }
}

/**
 * Generiert HTML für ein Formularfeld basierend auf dem Feldtyp
 *
 * @param array $field Die Felddaten aus der Datenbank
 * @param string $productId Die Produkt-ID für eindeutige Feldnamen
 * @return string Das HTML für das Formularfeld
 */
function generateFormFieldHtml($field, $productId) {
    // Generiere eindeutige aber anonyme Feld-IDs ohne Form-ID und Feld-ID anzuzeigen
    $fieldId = "field_" . md5($productId . '_' . $field['id']);
    $fieldName = "product_fields[{$productId}][{$field['field_name']}]";
    $required = $field['required'] ? 'required' : '';
    $requiredMark = $field['required'] ? '<span class="required-mark">*</span>' : '';
    
    $html = "<div class='form-group'>";
    $html .= "<label for='{$fieldId}'>" . htmlspecialchars($field['field_label']) . " {$requiredMark}</label>";
    
    switch ($field['field_type']) {
        case 'text':
            $html .= "<input type='text' id='{$fieldId}' name='{$fieldName}' class='form-control' {$required}>";
            break;
            
        case 'email':
            $html .= "<input type='email' id='{$fieldId}' name='{$fieldName}' class='form-control' {$required}>";
            break;
            
        case 'number':
            $html .= "<input type='number' id='{$fieldId}' name='{$fieldName}' class='form-control' {$required}>";
            break;
            
        case 'textarea':
            $html .= "<textarea id='{$fieldId}' name='{$fieldName}' class='form-control' rows='3' {$required}></textarea>";
            break;
            
        case 'select':
            $html .= "<select id='{$fieldId}' name='{$fieldName}' class='form-control' {$required}>";
            $html .= "<option value=''>Bitte wählen...</option>";
            
            // Optionen parsen, falls vorhanden - mit Zeilenwechseln statt Kommas
            if (!empty($field['field_options'])) {
                $options = explode("\n", $field['field_options']);
                foreach ($options as $option) {
                    $option = trim($option);
                    if (empty($option)) continue;
                    $html .= "<option value='" . htmlspecialchars($option) . "'>" . htmlspecialchars($option) . "</option>";
                }
            }
            
            $html .= "</select>";
            break;
            
        case 'radio':
            // Optionen parsen, falls vorhanden - mit Zeilenwechseln statt Kommas
            if (!empty($field['field_options'])) {
                $options = explode("\n", $field['field_options']);
                foreach ($options as $index => $option) {
                    $option = trim($option);
                    if (empty($option)) continue;
                    $optionId = "{$fieldId}_{$index}";
                    $html .= "<div class='radio-option'>";
                    $html .= "<input type='radio' id='{$optionId}' name='{$fieldName}' value='" . htmlspecialchars($option) . "' " . ($index === 0 && $required ? 'required' : '') . ">";
                    $html .= "<label for='{$optionId}'>" . htmlspecialchars($option) . "</label>";
                    $html .= "</div>";
                }
            }
            break;
            
        case 'checkbox':
            // Für mehrere Checkboxen mit Optionen
            if (!empty($field['field_options'])) {
                $options = explode("\n", $field['field_options']);
                foreach ($options as $index => $option) {
                    $option = trim($option);
                    if (empty($option)) continue;
                    $optionId = "{$fieldId}_{$index}";
                    $html .= "<div class='checkbox-option'>";
                    $html .= "<input type='checkbox' id='{$optionId}' name='{$fieldName}[]' value='" . htmlspecialchars($option) . "' " . ($required && $index === 0 ? 'required' : '') . ">";
                    $html .= "<label for='{$optionId}'>" . htmlspecialchars($option) . "</label>";
                    $html .= "</div>";
                }
            } else {
                // Einzelne Checkbox ohne Optionen
                $html .= "<div class='checkbox-field'>";
                $html .= "<input type='checkbox' id='{$fieldId}' name='{$fieldName}' value='1' {$required}>";
                $html .= "<label for='{$fieldId}'>" . htmlspecialchars($field['field_description'] ?? 'Auswählen') . "</label>";
                $html .= "</div>";
            }
            break;
            
        case 'date':
            $html .= "<input type='date' id='{$fieldId}' name='{$fieldName}' class='form-control' {$required}>";
            break;
            
        default:
            $html .= "<input type='text' id='{$fieldId}' name='{$fieldName}' class='form-control' {$required}>";
            break;
    }
    
    if (!empty($field['field_description']) && $field['field_type'] !== 'checkbox') {
        $html .= "<small class='form-text text-muted'>" . htmlspecialchars($field['field_description']) . "</small>";
    }
    
    $html .= "</div>";
    
    return $html;
}

/**
 * Generiert das komplette HTML für alle Formularfelder eines Produkts
 *
 * @param PDO $conn Die Datenbankverbindung
 * @param int $formId Die Formular-ID
 * @param int $productId Die Produkt-ID
 * @param string $productName Der Produktname für die Anzeige
 * @return string Das vollständige Formular-HTML
 */
function generateProductForm($conn, $formId, $productId, $productName) {
    $fields = loadFormFields($conn, $formId);
    
    if (empty($fields)) {
        return "<div class='alert alert-warning'>Keine Formularfelder für dieses Produkt verfügbar.</div>";
    }
    
    // Keine Form-ID im HTML anzeigen
    $html = "<div class='product-form'>";
    $html .= "<h3 class='product-form-title'>" . htmlspecialchars($productName) . " - Produktspezifische Informationen</h3>";
    
    foreach ($fields as $field) {
        $html .= generateFormFieldHtml($field, $productId);
    }
    
    $html .= "</div>";
    
    return $html;
}

/**
 * Zeigt ein dynamisches Formular für jedes Produkt im Warenkorb an
 *
 * @param PDO $conn Die Datenbankverbindung
 * @param array $products Die Produkte im Warenkorb
 * @return string Das HTML für alle Produktformulare
 */
function displayProductForms($conn, $products) {
    if (empty($products)) {
        return "";
    }
    
    $html = "<div class='product-specific-forms'>";
    $html .= "<h2 style='color: var(--primary-color); margin: 30px 0 20px;'>Produktspezifische Informationen</h2>";
    
    foreach ($products as $product) {
        if (!empty($product['form_id'])) {
            $html .= generateProductForm($conn, $product['form_id'], $product['id'], $product['name']);
        }
    }
    
    $html .= "</div>";
    
    return $html;
}

/**
 * Fügt zusätzliche CSS für die Formulare ein
 *
 * @return string Das CSS für die Formulare
 */
function getFormStyles() {
    return "
    <style>
        .product-specific-forms {
            margin-top: 40px;
            margin-bottom: 40px;
        }
        
        .product-form {
            background-color: #f9f9f9;
            border: 1px solid #eee;
            border-radius: 8px;
            padding: 20px;
            margin-bottom: 25px;
        }
        
        .product-form-title {
            color: var(--primary-color);
            border-bottom: 1px solid #ddd;
            padding-bottom: 10px;
            margin-bottom: 20px;
        }
        
        .radio-option {
            margin-bottom: 8px;
        }
        
        .checkbox-option {
            margin-bottom: 8px;
        }
        
        .checkbox-field {
            display: flex;
            align-items: center;
            gap: 10px;
        }
        
        .checkbox-field input[type='checkbox'],
        .checkbox-option input[type='checkbox'] {
            transform: scale(1.2);
        }
        
        /* Ensure Form IDs or technical IDs are not visible */
        [id*='form_id'], [data-form-id], [data-formid] {
            display: none !important;
        }
    </style>
    ";
}
?> 