<?php
error_reporting(E_ALL);
ini_set('display_errors', 1);

require_once('includes/db_connect.php');
require_once('includes/voucher_functions.php');

// Session starten für Gutschein-Daten
session_start();

// Protokollieren der eingehenden Daten
$logFile = 'order_log.txt';
file_put_contents($logFile, date('Y-m-d H:i:s') . ' - Neue Bestellung eingegangen. Daten: ' . print_r($_POST, true), FILE_APPEND);

// Prüfen, ob Formulardaten vorhanden sind
if ($_SERVER['REQUEST_METHOD'] !== 'POST' || !isset($_POST['customer_name']) || !isset($_POST['customer_email'])) {
    header('Location: order.php?error=missing_data');
    exit;
}

// Grundlegende Validierung
$customer_name = trim($_POST['customer_name']);
$customer_email = trim($_POST['customer_email']);
$customer_address = trim($_POST['customer_address']);
$customer_phone = isset($_POST['customer_phone']) ? trim($_POST['customer_phone']) : '';
$customer_message = isset($_POST['customer_message']) ? trim($_POST['customer_message']) : '';

if (empty($customer_name) || empty($customer_email) || empty($customer_address)) {
    header('Location: order_cart.php?error=empty_fields');
    exit;
}

if (!filter_var($customer_email, FILTER_VALIDATE_EMAIL)) {
    header('Location: order_cart.php?error=invalid_email');
    exit;
}

// Prüfen, ob Produkte und Mengen vorhanden sind
if (!isset($_POST['products']) || !is_array($_POST['products']) || !isset($_POST['quantities']) || !is_array($_POST['quantities'])) {
    header('Location: order.php?error=no_products');
    exit;
}

$products = $_POST['products'];
$quantities = $_POST['quantities'];

// Produktspezifische Formulardaten erfassen
$productFields = isset($_POST['product_fields']) ? $_POST['product_fields'] : [];

// Nur Produkte mit Mengen > 0 behalten
$orderProducts = [];
foreach ($quantities as $productId => $quantity) {
    if (intval($quantity) > 0 && isset($products[$productId])) {
        $formId = $products[$productId];
        if (!empty($formId)) {
            $orderProducts[$productId] = [
                'form_id' => $formId,
                'quantity' => intval($quantity)
            ];
        }
    }
}

// Wenn keine gültigen Produkte vorhanden sind, zurück zur Bestellseite
if (empty($orderProducts)) {
    header('Location: order.php?error=no_valid_products');
    exit;
}

// Gemeinsame Bestelldaten
$orderData = [
    'customer_name' => $customer_name,
    'customer_email' => $customer_email,
    'customer_address' => $customer_address,
    'customer_phone' => $customer_phone,
    'customer_message' => $customer_message
];
$orderDataJson = json_encode($orderData, JSON_UNESCAPED_UNICODE);

// Lade Produktinformationen
$productIds = array_keys($orderProducts);
$placeholders = implode(',', array_fill(0, count($productIds), '?'));

$stmt = $conn->prepare("
    SELECT id, name, image_path, short_description
    FROM products 
    WHERE id IN ($placeholders) AND active = 1
");

foreach ($productIds as $index => $id) {
    $stmt->bindValue($index + 1, $id);
}

$stmt->execute();
$productDetails = [];
while ($product = $stmt->fetch(PDO::FETCH_ASSOC)) {
    $productDetails[$product['id']] = $product;
}

// Gutschein-Verarbeitung
$appliedVoucher = null;
$discountAmount = 0;
$orderTotal = 0;

// Bestellsumme berechnen (nur für Produkte mit sichtbaren Preisen)
$stmt = $conn->prepare("
    SELECT id, price, show_price
    FROM products 
    WHERE id IN ($placeholders) AND active = 1
");

foreach ($productIds as $index => $id) {
    $stmt->bindValue($index + 1, $id);
}

$stmt->execute();
while ($product = $stmt->fetch(PDO::FETCH_ASSOC)) {
    if ($product['show_price'] && isset($orderProducts[$product['id']])) {
        $quantity = $orderProducts[$product['id']]['quantity'];
        $orderTotal += $product['price'] * $quantity;
    }
}

// Gutschein anwenden, falls vorhanden
if (isset($_SESSION['applied_voucher']) && $orderTotal > 0) {
    $voucherData = $_SESSION['applied_voucher'];
    
    // Gutschein nochmals validieren
    $validationResult = validateVoucher($conn, $voucherData['code'], $orderTotal);
    
    if ($validationResult['success']) {
        $appliedVoucher = $validationResult['voucher_data'];
        $discountAmount = $validationResult['discount_amount'];
        
        // Gutschein als verwendet markieren
        applyVoucher(
            $conn, 
            $appliedVoucher['id'], 
            $discountAmount, 
            $orderTotal, 
            $customer_email, 
            $customer_name
        );
        
        // Gutschein aus Session entfernen
        unset($_SESSION['applied_voucher']);
    }
}

// Bestellung in die Datenbank speichern
try {
    // Transaktion starten
    $conn->beginTransaction();
    
    // E-Mail-Inhalt vorbereiten
    $emailSubject = "Neue Bestellung von " . $customer_name;
    $emailBody = "Eine neue Bestellung wurde eingereicht:\n\n";
    $emailBody .= "Kunde: " . $customer_name . "\n";
    $emailBody .= "E-Mail: " . $customer_email . "\n";
    $emailBody .= "Adresse: " . $customer_address . "\n";
    
    if (!empty($customer_phone)) {
        $emailBody .= "Telefon: " . $customer_phone . "\n";
    }
    
    if (!empty($customer_message)) {
        $emailBody .= "Nachricht: " . $customer_message . "\n";
    }
    
    $emailBody .= "\nBestellte Produkte:\n";
    $insertSuccess = true;
    
    // Für jedes Produkt in der Bestellung
    foreach ($orderProducts as $productId => $data) {
        $formId = $data['form_id'];
        $quantity = $data['quantity'];
        $productName = isset($productDetails[$productId]) ? $productDetails[$productId]['name'] : "Produkt #" . $productId;
        
        // Produktspezifische Daten aus dem Formular
        $productData = isset($productFields[$productId]) ? $productFields[$productId] : [];
        
        // Kombiniere Kundendaten und produktspezifische Daten für submission_data
        $submissionData = array_merge($orderData, $productData);
        $submissionDataJson = json_encode($submissionData, JSON_UNESCAPED_UNICODE);
        
        // MySQL-kompatible Einfügeanweisung mit submission_data Spalte
        $sql = "INSERT INTO order_submissions (form_id, submission_date, customer_data, submission_data, quantity) 
                VALUES (:form_id, NOW(), :customer_data, :submission_data, :quantity)";
        
        $stmt = $conn->prepare($sql);
        $stmt->bindParam(':form_id', $formId);
        $stmt->bindParam(':customer_data', $orderDataJson);
        $stmt->bindParam(':submission_data', $submissionDataJson);  // Produktspezifische Daten
        $stmt->bindParam(':quantity', $quantity);
        
        // Ausführen und auf Erfolg prüfen
        if (!$stmt->execute()) {
            $insertSuccess = false;
            file_put_contents($logFile, date('Y-m-d H:i:s') . " - Fehler beim Einfügen von Produkt #$productId\n", FILE_APPEND);
            break;
        }
        
        // E-Mail-Inhalt ergänzen
        $emailBody .= "- " . $productName . " (Anzahl: " . $quantity . ")\n";
    }
    
    // Wenn alle Einfügungen erfolgreich waren, Transaktion bestätigen
    if ($insertSuccess) {
        $conn->commit();
        
        // Verbesserte E-Mail mit HTML-Formatierung
        $to = "info@ke-lo.xyz"; // Empfänger-E-Mail
        
        // HTML-Version der E-Mail
        $htmlMessage = "
        <!DOCTYPE html>
        <html>
        <head>
            <style>
                body { font-family: Arial, sans-serif; line-height: 1.6; color: #333; }
                .container { max-width: 600px; margin: 0 auto; padding: 20px; }
                .header { background-color: #8b6b4f; color: white; padding: 15px; text-align: center; }
                .content { padding: 20px; background-color: #f8f8f8; }
                .footer { padding: 15px; text-align: center; font-size: 12px; color: #777; }
                .customer-info { margin-bottom: 30px; }
                .products { width: 100%; border-collapse: collapse; margin-bottom: 30px; }
                .products th { background-color: #d4af37; color: white; text-align: left; padding: 8px; }
                .products td { border-bottom: 1px solid #ddd; padding: 8px; }
                h2 { color: #8b6b4f; }
            </style>
        </head>
        <body>
            <div class='container'>
                <div class='header'>
                    <h1>Neue Bestellung</h1>
                </div>
                <div class='content'>
                    <h2>Kundeninformationen</h2>
                    <div class='customer-info'>
                        <p><strong>Name:</strong> $customer_name</p>
                        <p><strong>E-Mail:</strong> $customer_email</p>
                        <p><strong>Adresse:</strong> $customer_address</p>
        ";
        
        if (!empty($customer_phone)) {
            $htmlMessage .= "<p><strong>Telefon:</strong> $customer_phone</p>";
        }
        
        if (!empty($customer_message)) {
            $htmlMessage .= "<p><strong>Nachricht:</strong> $customer_message</p>";
        }
        
        $htmlMessage .= "
                    </div>
                    
                    <h2>Bestellte Produkte</h2>
                    <table class='products'>
                        <tr>
                            <th>Produkt</th>
                            <th>Anzahl</th>
                        </tr>
        ";
        
        // Text-Version der E-Mail (als Fallback)
        $textMessage = "Eine neue Bestellung wurde eingereicht:\n\n";
        $textMessage .= "KUNDENINFORMATIONEN\n";
        $textMessage .= "-------------------\n";
        $textMessage .= "Name: " . $customer_name . "\n";
        $textMessage .= "E-Mail: " . $customer_email . "\n";
        $textMessage .= "Adresse: " . $customer_address . "\n";
        
        if (!empty($customer_phone)) {
            $textMessage .= "Telefon: " . $customer_phone . "\n";
        }
        
        if (!empty($customer_message)) {
            $textMessage .= "Nachricht: " . $customer_message . "\n";
        }
        
        $textMessage .= "\nBESTELLTE PRODUKTE\n";
        $textMessage .= "------------------\n";
        
        // Für jedes Produkt in der Bestellung
        foreach ($orderProducts as $productId => $data) {
            $quantity = $data['quantity'];
            $productName = isset($productDetails[$productId]) ? $productDetails[$productId]['name'] : "Produkt #" . $productId;
            
            // HTML-Version
            $htmlMessage .= "
                <tr>
                    <td>" . htmlspecialchars($productName) . "</td>
                    <td>" . $quantity . "</td>
                </tr>
            ";
            
            // Produktspezifische Felder anzeigen, falls vorhanden
            if (!empty($productFields[$productId])) {
                $htmlMessage .= "
                <tr>
                    <td colspan='2' style='padding: 0;'>
                        <table style='width: 100%; margin: 5px 0; background-color: #f5f5f5; font-size: 13px;'>
                            <tr><th colspan='2' style='text-align: left; padding: 5px; background-color: #eeeeee;'>Produktspezifische Informationen:</th></tr>
                ";
                
                foreach ($productFields[$productId] as $fieldName => $fieldValue) {
                    if (!empty($fieldValue)) {
                        $displayName = ucfirst(str_replace('_', ' ', $fieldName));
                        $htmlMessage .= "
                        <tr>
                            <td style='padding: 3px 5px; border-bottom: 1px solid #eee; width: 40%;'><strong>" . htmlspecialchars($displayName) . ":</strong></td>
                            <td style='padding: 3px 5px; border-bottom: 1px solid #eee;'>" . htmlspecialchars($fieldValue) . "</td>
                        </tr>
                        ";
                    }
                }
                
                $htmlMessage .= "
                        </table>
                    </td>
                </tr>
                ";
                
                // Auch für die Text-Version
                $textMessage .= "  Produktspezifische Informationen:\n";
                foreach ($productFields[$productId] as $fieldName => $fieldValue) {
                    if (!empty($fieldValue)) {
                        $displayName = ucfirst(str_replace('_', ' ', $fieldName));
                        $textMessage .= "  - " . $displayName . ": " . $fieldValue . "\n";
                    }
                }
                $textMessage .= "\n";
            }
            
            // Text-Version
            $textMessage .= "- " . $productName . " (Anzahl: " . $quantity . ")\n";
        }
        
        // HTML-E-Mail abschließen
        $htmlMessage .= "
                    </table>
        ";
        
        // Gutschein-Informationen hinzufügen, falls vorhanden
        if ($appliedVoucher && $orderTotal > 0) {
            $finalTotal = $orderTotal - $discountAmount;
            
            $htmlMessage .= "
                    <h2>Preisübersicht</h2>
                    <table class='products'>
                        <tr>
                            <td><strong>Zwischensumme:</strong></td>
                            <td style='text-align: right;'>" . number_format($orderTotal, 2, ',', '.') . " €</td>
                        </tr>
                        <tr style='color: #28a745;'>
                            <td><strong>Gutschein (" . htmlspecialchars($appliedVoucher['code']) . "):</strong></td>
                            <td style='text-align: right;'>-" . number_format($discountAmount, 2, ',', '.') . " €</td>
                        </tr>
                        <tr style='border-top: 2px solid #8b6b4f; font-size: 1.2em;'>
                            <td><strong>Gesamtsumme:</strong></td>
                            <td style='text-align: right;'><strong>" . number_format($finalTotal, 2, ',', '.') . " €</strong></td>
                        </tr>
                    </table>
            ";
            
            // Auch zur Text-Version hinzufügen
            $textMessage .= "\nPREISÜBERSICHT\n";
            $textMessage .= "--------------\n";
            $textMessage .= "Zwischensumme: " . number_format($orderTotal, 2, ',', '.') . " €\n";
            $textMessage .= "Gutschein (" . $appliedVoucher['code'] . "): -" . number_format($discountAmount, 2, ',', '.') . " €\n";
            $textMessage .= "Gesamtsumme: " . number_format($finalTotal, 2, ',', '.') . " €\n";
        } elseif ($orderTotal > 0) {
            $htmlMessage .= "
                    <h2>Preisübersicht</h2>
                    <table class='products'>
                        <tr style='border-top: 2px solid #8b6b4f; font-size: 1.2em;'>
                            <td><strong>Gesamtsumme:</strong></td>
                            <td style='text-align: right;'><strong>" . number_format($orderTotal, 2, ',', '.') . " €</strong></td>
                        </tr>
                    </table>
            ";
            
            $textMessage .= "\nPREISÜBERSICHT\n";
            $textMessage .= "--------------\n";
            $textMessage .= "Gesamtsumme: " . number_format($orderTotal, 2, ',', '.') . " €\n";
        }
        
        $htmlMessage .= "
                    <p>Diese Bestellung wurde soeben über das Online-Formular eingereicht.</p>
                </div>
                <div class='footer'>
                    <p>© " . date('Y') . " JB Kerzen. Alle Rechte vorbehalten.</p>
                </div>
            </div>
        </body>
        </html>
        ";
        
        // E-Mail-Header für HTML-E-Mail
        $headers = "From: noreply@" . $_SERVER['HTTP_HOST'] . "\r\n";
        $headers .= "Reply-To: " . $customer_email . "\r\n";
        $headers .= "MIME-Version: 1.0\r\n";
        $headers .= "Content-Type: multipart/alternative; boundary=\"boundary\"\r\n";
        
        // Multipart E-Mail erstellen (Text und HTML)
        $message = "--boundary\r\n";
        $message .= "Content-Type: text/plain; charset=UTF-8\r\n";
        $message .= "Content-Transfer-Encoding: 8bit\r\n\r\n";
        $message .= $textMessage . "\r\n";
        
        $message .= "--boundary\r\n";
        $message .= "Content-Type: text/html; charset=UTF-8\r\n";
        $message .= "Content-Transfer-Encoding: 8bit\r\n\r\n";
        $message .= $htmlMessage . "\r\n";
        
        $message .= "--boundary--";
        
        // E-Mail senden
        mail($to, $emailSubject, $message, $headers);
        
        file_put_contents($logFile, date('Y-m-d H:i:s') . " - Bestellung erfolgreich abgeschlossen\n", FILE_APPEND);
        
        // Zur Erfolgsseite weiterleiten
        header("Location: order_success.php");
        exit;
    } else {
        // Bei Fehler Transaktion zurückrollen
        $conn->rollBack();
        file_put_contents($logFile, date('Y-m-d H:i:s') . " - Bestellung fehlgeschlagen (Transaktion zurückgerollt)\n", FILE_APPEND);
        header("Location: order_cart.php?error=db_error");
        exit;
    }
    
} catch (PDOException $e) {
    // Bei Ausnahme Transaktion zurückrollen
    if ($conn->inTransaction()) {
        $conn->rollBack();
    }
    
    // Fehler protokollieren
    file_put_contents($logFile, date('Y-m-d H:i:s') . " - Datenbankfehler: " . $e->getMessage() . "\n", FILE_APPEND);
    
    // Zurück zum Warenkorb mit Fehlermeldung
    header("Location: order_cart.php?error=db_error&message=" . urlencode($e->getMessage()));
    exit;
}
?> 